<?php
require '../vendor/autoload.php';
include 'config.php';

$app = new Slim\App(["settings" => $config]);

//Handle Dependencies
$container = $app->getContainer();

$container['apidb'] = function ($c) {
   
   try {
       $db = $c['settings']['apidb'];
       $options  = array(PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION, PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC, );
       $pdo = new PDO("mysql:host=" . $db['servername'] . ";dbname=" . $db['dbname'], $db['username'], $db['password'],$options);
       return $pdo;
   }
   catch(\Exception $ex) {
       return $ex->getMessage();
   }
};

// Add the authentication function to the API execution stack 
$app->add( function ( $request, $response, $next ) {
    $auth_header = $request->getHeaderLine('authorization');

    $auths = explode(',', $auth_header );
    $auth_key;

    if(count($auths) < 2)
        $auth_key = $auths[0];
    else {
        $auth_key = $auths[0];
    }

    // Validate the Authorization Key
    if ( isset( $auth_key ) ) {
		
        try{
            $con = $this->apidb;
            $sql = "SELECT id FROM tblStore where auth_key = :auth_key";
            $pre = $con->prepare($sql, array(PDO::ATTR_CURSOR => PDO::CURSOR_FWDONLY));
            $values = array( ':auth_key' => $auth_key );
            $pre->execute($values);
            $result = $pre->fetch();
        }
        catch(\Exception $ex) {
            return $response->withJson( array( 'error' => true, 'message' => 'Could not authenticate.' ), 400 );
        }
		
        if ( !$result ) {
            return $response->withJson( array( 'error' => true, 'message' => 'Invalid Api key.' ), 401 );
            // $app->stop();
        } 

        $response = $next($request, $response);
        return $response;
		
    } else {
        return $response->withJson( array( 'error' => true, 'message' => 'Api key is misssing.' ), 400 );
        // $app->stop();
    }
});

// Let the world know that we are live!
$app->get('/', function() {
    return $response->withJson(array('status' => 'active','message'=> 'Welcome to Leonardo Fifth Avenue API.'),200);
});

$app->post('/register', function ($request, $response) {
    try {
        $params = $request->getParsedBody()['form'];
           
        $con = $this->apidb;
        $sql = "insert into tblNewCollectionLayaway (store, 
                                                    gender, 
                                                    product_type, 
                                                    product, 
                                                    size, 
                                                    client_name, 
                                                    client_phone
                                                    ) values (
                                                    :store,
                                                    :gender,
                                                    :product_type,
                                                    :product,
                                                    :size,
                                                    :client_name,
                                                    :client_phone)";
        $pre = $con->prepare($sql, array(PDO::ATTR_CURSOR => PDO::CURSOR_FWDONLY));
        $values = array(
            ':store' => $params['store'],
            ':gender' => $params['gender'],
            ':product_type' => $params['productType'],
            ':product' => $params['product'],
            ':size' => $params['size'],
            ':client_name' => $params['clientName'],
            ':client_phone' => $params['clientPhone']
        );
        $pre->execute( $values );

        return $response->withJson(array('status' => true,'message'=> 'Success'), 200);       
    }
    catch(\Exception $ex) {
        return $response->withJson(array('error' => $ex->getMessage()),422);
    }
 });

 $app->run();