<?php

/**
 * RMH calls class.
 *
 * @author  Softech Corporation
 * @since 1.0.0
 */
class RMH {

    /**
     * API base URL.
     *
     * @var     string
     * @access  private
     * @since   1.0.0
     */
    private $api_base_url = '67.203.200.74:809/api/';

    /**
     * API base URL (development).
     *
     * @var     string
     * @access  private
     * @since   1.0.0
     */
    private $api_base_url_dev = '67.203.200.74:809/api/';

    /**
     * Set if the requests should be using the http secure protocol (https).
     *
     * @var     bool
     * @access  public
     * @since   1.0.0
     */
    public $is_https = false;

    /**
     * Set if the request should be made to the development or production environment.
     *
     * @var     bool
     * @access  public
     * @since   1.0.0
     */
    public $is_debug = true;

    /**
     * Class constructor.
     *
     * @since 1.0.0
     */
    public function __construct( $secure, $debug ) {
        // put constructor code here
        $this->is_debug = $debug;
        $this->is_https = $secure;
    }

    /**
     * Get the API call protocol.
     *
     * @return string
     * @since 1.0.0
     */
    private function get_protocol () {
        if ( $this->is_https )
            return 'https://';
        
        return 'http://';
    }

    /**
     * Get the API base URL with the correct protocol ( http or https ).
     *
     * @return string
     * @since 1.0.0
     */
    private function get_api_url () {
        if ( $this->is_debug )
            return $this->get_protocol() . $this->api_base_url_dev;

        return $this->get_protocol() . $this->api_base_url;
    }

    public function create_order( $order, $user ) {

        // Get token
        $token_request = $this->get_token( $user );
        $token = '';
        if( $token_request['error'] ) {
            return array('status' => true, 'error' => true, 'message' => $token_request['message'] );
        }

        return array('status' => true, 'error' => false, 'message' => $token_request );

        if( !empty( $token_request['token'] ) )
            $token = $token_request['token'];

        if( empty( $token ) ) {
            return array('status' => true, 'error' => false, 'message' => 'Access denied to RMH.' );
        }

        $details = array();
        $charges = array();

        foreach( $order['items'] as $item ) {
            array_push( $details, array(
                'item_id'       => $item['product_id'],
                'order_id'      => $order['id'],
                'product_name'  => $item['description'],
                'qty'           => 1,
                'price'         => $item['price'],
                'total'         => $item['price']
            ));
        }

        foreach( $order['promos'] as $promo ) {
            array_push( $charges, array(
                'order_id'  => $order['id'],
                'concept'   => $promo['other_charges_type'],
                'amount'    => $promo['amount'],
                'code'      => $promo['code']
            ));
        }

        $body = array(
            "id"                            => $order['id'],
            "order_date"                    => $order['date'],
            "customer_id"                   => $order['customer']['id'],
            "subtotal"                      => $order['subtotal'],
            "other_charges_discount"        => $order['other_charges_discount'],
            "tax"                           => $order['tax'],
            "shipping"                      => $order['shipping'],
            "total"                         => $order['total'],
            "details"                       => $details,
            "charges"                       => $charges
        );

        // save order in RMH
        $wsdl = $this->get_api_url() . 'Order/create';
        $curl = curl_init($wsdl);
        curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'POST');
        curl_setopt($curl, CURLOPT_POST, TRUE);
        curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode( $body ) );
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false); //IMP if the url has https and you don't want to verify source certificate
        $headers = array();
        $headers[] = 'Authorization: Bearer ' . $token;
        $headers[] = 'Content-Type: application/json';
        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
        $curl_response = curl_exec($curl);
        curl_close($curl);
        $response = json_decode($curl_response,true);

        if ( $response['id'] == 0 )
            return array('status' => false, 'error' => true, 'message' => $response['message'] );
        else
            return array('status' => true, 'error' => false, 'message' => 'Success' );
    }

    private function get_token( $user ) {

        $body = array(
            'grant_type'    => 'password',
            'username'      => $user->email,
            'password'      => $user->rmhPassword
        );
        
        $wsdl = str_replace( "/api", "", $this->get_api_url() ) . 'token';
        $curl = curl_init($wsdl);
        curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'POST');
        curl_setopt($curl, CURLOPT_POST, TRUE);
        curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode( $body ) ); //'grant_type=password&username=' . urlencode( $user->email ) . '&password=' . urlencode( $user->rmhPassword ) );
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false); //IMP if the url has https and you don't want to verify source certificate
        $headers = array();
        $headers[] = 'Content-Type: application/x-www-form-urlencoded';
        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
        $curl_response = curl_exec($curl);
        curl_close($curl);
        $response = json_decode($curl_response,true);

        return $response;

        if ( $response['error'] )
            return array('status' => false, 'error' => true, 'message' => $response['message'] );
        else
            return array('status' => true, 'error' => false, 'token' => $response['access_token'] );
    }
}