<?php
/**
 * Wintux calls class.
 *
 * @author  Softech Corporation
 * @since 1.0.0
 */
class Wintux {

    /**
     * API authentication key.
     *
     * @var     string
     * @access  private
     * @since   1.0.0
     */
    private $api_key = 'c31aa28e6b58e2e69dd457f99e2646e3';

    /**
     * People to notify if the service is down for any reason.
     *
     * @var     string
     * @access  private
     * @since   1.0.0
     */
    private $fail_notification_email = 'msantiago@leonardos.com';

    /**
     * API base URL.
     *
     * @var     string
     * @access  private
     * @since   1.0.0
     */
    private $api_base_url = 'leonardos.waocloud.com:8474/app/v2/index.php/';

    /**
     * API base URL (development).
     *
     * @var     string
     * @access  private
     * @since   1.0.0
     */
    private $api_base_url_dev = '67.203.200.74:8474/app/v2/index.php/';

    /**
     * Store (development).
     *
     * @var     string
     * @access  private
     * @since   1.0.0
     */
    private $store = 'pr';

    /**
     * Set if the requests should be using the http secure protocol (https).
     *
     * @var     bool
     * @access  public
     * @since   1.0.0
     */
    public $is_https = false;

    /**
     * Set if the request should be made to the development or production environment.
     *
     * @var     bool
     * @access  public
     * @since   1.0.0
     */
    public $is_debug = true;

    /**
     * Class constructor.
     *
     * @since 1.0.0
     */
    public function __construct( $store, $secure, $debug ) {
        // put constructor code here
        $this->store = $store;
        $this->is_debug = $debug;
        $this->is_https = $secure;
    }

    /**
     * Get the API call protocol.
     *
     * @return string
     * @since 1.0.0
     */
    private function get_protocol () {
        if ( $this->is_https )
            return 'https://';
        
        return 'http://';
    }

    /**
     * Get the API base URL with the correct protocol ( http or https ).
     *
     * @return string
     * @since 1.0.0
     */
    private function get_api_url () {
        if ( $this->is_debug )
            return $this->get_protocol() . $this->api_base_url_dev;

        return $this->get_protocol() . $this->api_base_url;
    }

    public function get_event_info( $event_code ) {

        if( !is_int($event_code) ) {
            throw new Exception('Invalid event code');
        }

        $wsdl = $this->get_api_url() . 'findevent/' . $event_code . '?store=' . $this->store;
        
		$curl = curl_init($wsdl);
		
		curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'GET');
        curl_setopt($curl, CURLOPT_ENCODING, '');
        curl_setopt($curl, CURLOPT_MAXREDIRS, 10);
        curl_setopt($curl, CURLOPT_TIMEOUT, 30);
        curl_setopt($curl, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
		$headers = array();
		$headers[] = 'Authorization: ' . $this->api_key;
		curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
		$curl_response = curl_exec($curl);
		curl_close($curl);
		$response = json_decode($curl_response,true);
		if(sizeof($response)==0)
			mail( $this->fail_notification_email, 'Wintux web service error', 'Wintux web service is not available or did not answer. Check this URL ' . $wsdl );

		return $response;
    }

    public function create_event( $event ) {
        $wsdl = $this->get_api_url() . 'createevent?store=' . $this->store;

        $curl = curl_init($wsdl);
        curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'POST');
        curl_setopt($curl, CURLOPT_POST, TRUE);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query( $event ) );
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false); //IMP if the url has https and you don't want to verify source certificate
        $headers = array();
        $headers[] = 'Authorization: '.$this->api_key;
        $headers[] = 'Content-Type: application/x-www-form-urlencoded';
        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
        $curl_response = curl_exec($curl);
        curl_close($curl);
        $response = json_decode($curl_response,true);
        
		if( sizeof( $response ) == 0 )
			mail( $this->fail_notification_email, 'Wintux web service error', 'Wintux web service is not available or did not answer. Check this URL ' . $wsdl );

		return $response;
    }

    public function save_participant_outfit( $outfit ) {
        $wsdl = $this->get_api_url() . 'saveoutfit?store=' . $this->store;

        $curl = curl_init($wsdl);
        curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'POST');
        curl_setopt($curl, CURLOPT_POST, TRUE);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $outfit);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false); //IMP if the url has https and you don't want to verify source certificate
        $headers = array();
        $headers[] = 'Authorization: '.$this->api_key;
        $headers[] = 'Content-Type: application/x-www-form-urlencoded';
        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
        $curl_response = curl_exec($curl);
        curl_close($curl);
        $response = json_decode($curl_response,true);
        
		if(sizeof($response)==0)
			mail( $this->fail_notification_email, 'Wintux web service error', 'Wintux web service is not available or did not answer. Check this URL ' . $wsdl );

		return $response;
    }

    public function is_item_available( $sku, $size, $event_date ) {
        // $sku = sku . '||' . size . '||' . pickupDate . '||' . returnDate
        $sku .= '||' . $size . '||' . date( 'Y-m-d',strtotime( $event_date . ' -1 day' ) ) . '||' . date( 'Y-m-d',strtotime( $event_date . ' +1 day' ) );
        $wsdl = $this->get_api_url() . 'rentaldate/{sku}?store=' . $this->store;
        $wsdl = str_replace( '{sku}', $sku, $wsdl );
        
        $curl = curl_init($wsdl);
        curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'GET');
        curl_setopt($curl, CURLOPT_POST, false);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $body);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false); //IMP if the url has https and you don't want to verify source certificate
        $headers = array();
        $headers[] = 'Authorization: '.$this->api_key;
        $headers[] = 'Content-Type: multipart/form-data';
        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
        $curl_response = curl_exec($curl);
        curl_close($curl);
        $response = json_decode($curl_response,true);

        if ( $response['error'] )
            return array('error' => true, 'message' => $response['message'] );
        else
            return $response;
    }

    public function is_shop_item_available( $sku, $size ) {
        // $sku = sku . size
        $sku .= $size;
        $wsdl = $this->get_api_url() . 'salessku/{sku}?store=' . $this->store;
		$wsdl = str_replace( '{sku}', $sku, $wsdl );
		
        $response = wp_remote_get( $wsdl, array ( 'headers' => array ( 'Authorization' => $this->api_key ) ) );
        if ( is_array( $response ) ) {
            //$header = $response['headers']; // array of http header lines
            $body = $response['body']; // use the content
            return json_decode ( $body, true );
        }
        else {
            $errors = $response->get_error_code();
            return $response->get_error_message($errors);
        }
    }

    public function create_reservation( $order, $user ) {

        $account = '002';
        if ( $order['pickup_location_id'] == '9' ) // caguas
            $account = '005';
        else if ( $reservation['pickup_location_id'] == '6' ) // bayamon
            $account = '003';
        else if ( $reservation['pickup_location_id'] == '5' ) // 65
            $account = '001';
        else if ( $reservation['pickup_location_id'] == '11' ) // Arecibo
            $account = '007';
        else if ( $reservation['pickup_location_id'] == '7' ) // Mayaguez
            $account = '008';
        else if ( $reservation['pickup_location_id'] == '10' ) // Ponce
            $account = '011';
        else if ( $reservation['pickup_location_id'] == '8' ) // Cataño
            $account = '012';
        else if ( $reservation['pickup_location_id'] == '4' ) // San Juan
            $account = '002';
        
        $body = array(
            'val_transaction_n' => $order['wintux_store_id'] . '-' . $order['id'],
            'val_account_n' => $account, // Numer de tienda
            'val_clerk_n' => '1730',
            'val_want' => date( 'Y-m-d',strtotime( $order['want_date'] ) ), // Fecha del evento menos 1 dia
            'val_use' => date( 'Y-m-d',strtotime( $order['want_date'] ) ), // fecha del evento
            'val_occasion' => '', 
            'val_customername' => $order['customer']['full_name'],
            'val_address1' => $order['customer']['address_line1'] . ' ' . $order['customer']['address_line2'],
            'val_city' => $order['customer']['address_city'],
            'val_state' => $order['customer']['address_state'],
            'val_zipcode' => $order['customer']['address_zipcode'],
            'val_homephone' => $order['customer']['phone'],
            'val_coatstyle_n' => '', // sku sin size
            'val_coatsize' => '', // size
            'val_coatalteration' => '', // largo de manga de la camisa - 10
            'val_pantsstyle_n' => '', // sku
            'val_pantswaist' => '', // waist size
            'val_pantsoutseam' => '', // inseam + 10
            'val_shirtstyle_n' => '', // sku
            'val_shirtsize' => '', // size
            'val_jewelrystyle_n' => '', // sku
            'val_accessorystyle_n' => '', // sku
            'val_accessorysize' => '', // si es faja es FA, si es vest ???
            'val_tiestyle_n' => '', // sku
            'val_tiesize' => '', // si el size de chaqueta tiene B, entonce B, de lo contrario FA
            'val_shoestyle_n' => '', // sku
            'val_shoesize' => '', // size
            'val_otherstyle_n' => '', // [medias y panuelo] sku
            'val_othersize' => '', // FA
            'val_other2style_n' => '', // ???
            'val_other2size' => '', // ???
            'val_other3style_n' => '', // ???
            'val_other3size' => '', // ???
            'val_commentsmemo' => $reservation['comments'],
            'val_changed' => 'False', // ???
            'val_rentalprice' => $order['total'], // total
            'val_tax' => $order['tax'],
            'val_payment' => 0,
            'val_ShipByDate' => date( 'Y-m-d',strtotime( $order['want_date'] ) ), // want date
            'val_InStoreWantDate' => date( 'Y-m-d',strtotime( $order['want_date'] ) ), // want date
            'val_CustomerpickupDate' => date( 'Y-m-d',strtotime( $order['want_date'] ) ),
            'val_FirstDateofUse' => date( 'Y-m-d',strtotime( $order['use_date'] ) ), // ???
            'val_CustomerReturnDate' => date( 'Y-m-d',strtotime( $order['return_date'] ) ),
            'val_InStockDate' => date( 'Y-m-d',strtotime( $order['return_date'] ) ),
            'val_Status' => $order['status_id'],
            'val_DamageWaiver' => 10,
            'val_DateBooked' => date( 'Y-m-d' ),
            'val_StatusDate' => date( 'Y-m-d' )
        );

        foreach( $order['items'] as $item )  {

            if( $item['category_id'] == 'C' ) {
                $body['val_coatstyle_n'] = $item['style'];
                $body['val_coatsize'] = $order['customer']['measurements']['coat_size'] . $order['customer']['measurements']['coat_length'];
                $body['val_coatalteration'] = $order['customer']['measurements']['coat_sleeve'];
            }
            else if( $item['category_id'] == 'P' ) {
                $pantsw = '';
                if( in_array( $order['customer']['measurements']['pant_waist'], array( 27, 28, 29 ) ) ) $pantsw = '28R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 30, 31, 32 ) ) ) $pantsw = '31R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 33, 34, 35 ) ) ) $pantsw = '34R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 36, 37, 38 ) ) ) $pantsw = '37R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 39, 40, 41 ) ) ) $pantsw = '40R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 42, 43, 44 ) ) ) $pantsw = '43R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 45, 46, 47 ) ) ) $pantsw = '46R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 48, 49, 50 ) ) ) $pantsw = '49R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 51, 52, 53 ) ) ) $pantsw = '52R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 54, 55, 56 ) ) ) $pantsw = '55R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 57, 58, 59 ) ) ) $pantsw = '58R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 60, 61, 62 ) ) ) $pantsw = '61R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 63, 64, 65 ) ) ) $pantsw = '64R'; 
                else if( in_array( $order['customer']['measurements']['pant_waist'], array( 66, 67, 68 ) ) ) $pantsw = '67R'; 

                $body['val_pantsstyle_n'] = $item['style'];
                $body['val_pantswaist'] = $pantsw;
                $body['val_pantsoutseam'] = $order['customer']['measurements']['pant_outseam']; 
            }
            else if( $item['category_id'] == 'S' && empty( $body['val_shirtstyle_n'] ) ) {
                $body['val_shirtstyle_n'] = $item['style'];
                $body['val_shirtsize'] = $order['customer']['measurements']['shirt_size']; 
            }
            else if ( $item['category_id'] == 'S' ) {
                if( empty( $body['val_otherstyle_n'] ) ) {
                    $body['val_otherstyle_n'] = $item['style'];
                    $body['val_othersize'] = $order['customer']['measurements']['shirt_size']; 
                }
                else if ( empty( $body['val_other2style_n'] ) ) {
                    $body['val_other2style_n'] = $item['style'];
                    $body['val_other2size'] = $order['customer']['measurements']['shirt_size']; 
                }
                else if ( empty( $body['val_other3style_n'] ) ) {
                    $body['val_other3style_n'] = $item['style'];
                    $body['val_other3size'] = $order['customer']['measurements']['shirt_size']; 
                }
            }
            else if( ( $item['category_id'] == 'V' || $item['category_id'] == 'CB' ) && empty( $body['val_accessorystyle_n'] ) ) {
                $body['val_accessorystyle_n'] = $item['style']; 
                $body['val_accessorysize'] = ''; 
            }
            else if( $item['category_id'] == 'V' || $item['category_id'] == 'CB' ) {
                if( empty( $body['val_otherstyle_n'] ) ) {
                    $body['val_otherstyle_n'] = $item['style'];
                    $body['val_othersize'] = ''; 
                }
                else if ( empty( $body['val_other2style_n'] ) ) {
                    $body['val_other2style_n'] = $item['style'];
                    $body['val_other2size'] = ''; 
                }
                else if ( empty( $body['val_other3style_n'] ) ) {
                    $body['val_other3style_n'] = $item['style'];
                    $body['val_other3size'] = ''; 
                }
            }
            else if( $item['category_id'] == 'SH' && empty( $body['val_shoestyle_n'] ) ) {
                $body['val_shoestyle_n'] = $item['style']; 
                $body['val_shoesize'] = $order['customer']['measurements']['shoe_size'];
            }
            else if( $item['category_id'] == 'SH' ) {
                if( empty( $body['val_otherstyle_n'] ) ) {
                    $body['val_otherstyle_n'] = $item['style'];
                    $body['val_othersize'] = $order['customer']['measurements']['shoe_size'];
                }
                else if ( empty( $body['val_other2style_n'] ) ) {
                    $body['val_other2style_n'] = $item['style'];
                    $body['val_other2size'] = $order['customer']['measurements']['shoe_size'];
                }
                else if ( empty( $body['val_other3style_n'] ) ) {
                    $body['val_other3style_n'] = $item['style'];
                    $body['val_other3size'] = $order['customer']['measurements']['shoe_size'];
                }
            }
            else if( $item['category_id'] == 'J' && empty( $body['val_jewelrystyle_n'] ) ) {
                $body['val_jewelrystyle_n'] = $item['style']; 
            }
            else if( $item['category_id'] == 'J' ) {
                if( empty( $body['val_otherstyle_n'] ) ) {
                    $body['val_otherstyle_n'] = $item['style'];
                    $body['val_othersize'] = '';
                }
                else if ( empty( $body['val_other2style_n'] ) ) {
                    $body['val_other2style_n'] = $item['style'];
                    $body['val_other2size'] = '';
                }
                else if ( empty( $body['val_other3style_n'] ) ) {
                    $body['val_other3style_n'] = $item['style'];
                    $body['val_other3size'] = '';
                }
            }
            else if( $item['category_id'] == 'H' || $item['category_id'] == 'SO' ) { // SO = Socks
                if( empty( $body['val_otherstyle_n'] ) ) {
                    $body['val_otherstyle_n'] = $item['style'];
                    $body['val_othersize'] = 'FA';
                }
                else if ( empty( $body['val_other2style_n'] ) ) {
                    $body['val_other2style_n'] = $item['style'];
                    $body['val_other2size'] = 'FA';
                }
                else if ( empty( $body['val_other3style_n'] ) ) {
                    $body['val_other3style_n'] = $item['style'];
                    $body['val_other3size'] = 'FA';
                }
            }
            else if( ( $item['category_id'] == 'T' || $item['category_id'] == 'B' ) && empty( $body['val_tiestyle_n'] ) ) {
                $body['val_tiestyle_n'] = $item['style'];
                $body['val_tiesize'] = 'FA';
            }
            else if( $item['category_id'] == 'T' || $item['category_id'] == 'B' ) {
                if( empty( $body['val_otherstyle_n'] ) ) {
                    $body['val_otherstyle_n'] = $item['style'];
                    $body['val_othersize'] = 'FA';
                }
                else if ( empty( $body['val_other2style_n'] ) ) {
                    $body['val_other2style_n'] = $item['style'];
                    $body['val_other2size'] = 'FA';
                }
                else if ( empty( $body['val_other3style_n'] ) ) {
                    $body['val_other3style_n'] = $item['style'];
                    $body['val_other3size'] = 'FA';
                }
            }
        }

        // save order on Wintux
        $wsdl = $this->get_api_url() . 'rentalfull/?store=pr';
        $curl = curl_init($wsdl);
        curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'POST');
        curl_setopt($curl, CURLOPT_POST, TRUE);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $body);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false); //IMP if the url has https and you don't want to verify source certificate
        $headers = array();
        $headers[] = 'Authorization: '.$this->api_key;
        $headers[] = 'Content-Type: application/x-www-form-urlencoded';
        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
        $curl_response = curl_exec($curl);
        curl_close($curl);
        $response = json_decode($curl_response,true);

        if ( $response['error'] )
            return array('error' => true, 'message' => $response['message'] );
        else
            return $order['wintux_store_id'] . '-' . $order['id'];
    }

    public function get_wintux_pant_size( $waist ) {
        $pantsw = '';
        if( in_array( $waist, array( 27, 28, 29 ) ) ) $pantsw = '28R'; 
        else if( in_array( $waist, array( 30, 31, 32 ) ) ) $pantsw = '31R'; 
        else if( in_array( $waist, array( 33, 34, 35 ) ) ) $pantsw = '34R'; 
        else if( in_array( $waist, array( 36, 37, 38 ) ) ) $pantsw = '37R'; 
        else if( in_array( $waist, array( 39, 40, 41 ) ) ) $pantsw = '40R'; 
        else if( in_array( $waist, array( 42, 43, 44 ) ) ) $pantsw = '43R'; 
        else if( in_array( $waist, array( 45, 46, 47 ) ) ) $pantsw = '46R'; 
        else if( in_array( $waist, array( 48, 49, 50 ) ) ) $pantsw = '49R'; 
        else if( in_array( $waist, array( 51, 52, 53 ) ) ) $pantsw = '52R'; 
        else if( in_array( $waist, array( 54, 55, 56 ) ) ) $pantsw = '55R'; 
        else if( in_array( $waist, array( 57, 58, 59 ) ) ) $pantsw = '58R'; 
        else if( in_array( $waist, array( 60, 61, 62 ) ) ) $pantsw = '61R'; 
        else if( in_array( $waist, array( 63, 64, 65 ) ) ) $pantsw = '64R'; 
        else if( in_array( $waist, array( 66, 67, 68 ) ) ) $pantsw = '67R';

        return $pantsw;
    }

    public function get_order_status( $order_id ) {
        
        if( empty( $order_id ) )
            return null;

        $wsdl = $this->get_api_url() . 'orderstatus/{order_id}?store=' . $this->store;
        $wsdl = str_replace( '{order_id}', $order_id, $wsdl );
        
        $curl = curl_init($wsdl);
        curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'GET');
        curl_setopt($curl, CURLOPT_POST, false);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $body);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false); //IMP if the url has https and you don't want to verify source certificate
        $headers = array();
        $headers[] = 'Authorization: '.$this->api_key;
        $headers[] = 'Content-Type: multipart/form-data';
        curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
        $curl_response = curl_exec($curl);
        curl_close($curl);
        $response = json_decode($curl_response,true);

        $res = array();
        if( !empty( $response ) ) {
            $res['status'] = $response['content'];
            switch( $status ) {
                case '-5':
                    $res['status_description'] = 'Not Fitted';
                  break;
                case '-1':
                    $res['status_description'] = 'New Order';
                  break;
                case '0':
                    $res['status_description'] = 'Not Printed';
                  break;
                case '3':
                    $res['status_description'] = 'Processing';
                  break;
                case '4':
                    $res['status_description'] = 'QC Processing';
                  break;
                case '6':
                    $res['status_description'] = 'Shipping';
                  break;
                case '7':
                    $res['status_description'] = 'Truck Line';
                  break;
                case '9':
                    $res['status_description'] = 'Store Rack';
                  break;
                case '11':
                    $res['status_description'] = 'Out Not Billed';
                  break;
                case '12':
                    $res['status_description'] = 'Out on Rental';
                  break;
                case '15':
                    $res['status_description'] = 'Cancelled';
                  break;
                case '16':
                    $res['status_description'] = 'Void';
                  break;
                case '18':
                    $res['status_description'] = 'Partial Ret.';
                  break;
                case '21':
                    $res['status_description'] = 'Returned';
                  break;
                case '22':
                    $res['status_description'] = 'Not Picked Up';
                  break;
                case '24':
                    $res['status_description'] = 'Inactive';
                  break;
            }
        }

        if ( empty( $res ) )
            return array('error' => true, 'message' => $response );
        else
            return array('error' => false, 'content' => $res );
    }
}