Vue.component("m2m-coupon-list", {
    template: `
    <div>
        <m2m-loading :loading="this.loading">
            <v-card flat>
                <v-card-title primary-title>
                    <v-layout row>
                        <v-flex xs8>
                            <div class="title">Coupons</div>
                        </v-flex>
                        <v-flex xs4 class="text-xs-right">
                            <v-dialog v-model="dialog" fullscreen hide-overlay transition="dialog-bottom-transition">
                                <v-btn small right class="ma-0" slot="activator" v-if="isEditable">Add New</v-btn>
                                <v-card dark>
                                    <v-toolbar dark color="primary">
                                        <v-btn icon dark @click="closeDialog">
                                            <v-icon>close</v-icon>
                                        </v-btn>
                                        <v-toolbar-title>{{ this.dialogTitle }}</v-toolbar-title>
                                        <v-spacer></v-spacer>
                                        <v-toolbar-items>
                                            <v-btn dark flat @click="saveCoupon">Save</v-btn>
                                        </v-toolbar-items>
                                    </v-toolbar>
                                    <v-subheader>General Information</v-subheader>
                    
                                    <v-form ref="form" lazy-validation class="pa-3">
                                        <v-text-field label="Code" v-model="couponCode" :disabled="isEdit"></v-text-field>
                                        <v-menu :close-on-content-click="false" v-model="dateMenuFrom" :nudge-right="40" lazy transition="scale-transition" offset-y full-width min-width="290px">
                                            <v-text-field slot="activator" v-model="validFrom" label="Valid From" prepend-icon="event" @input="" readonly></v-text-field>
                                            <v-date-picker v-model="dateFrom" @input="dateMenuFrom = false" header-color="primary" :min="today"></v-date-picker>
                                        </v-menu>
                                        <v-menu :close-on-content-click="false" v-model="dateMenuTo" :nudge-right="40" lazy transition="scale-transition" offset-y full-width min-width="290px">
                                            <v-text-field slot="activator" v-model="validTo" label="Valid To" prepend-icon="event" @input="" readonly></v-text-field>
                                            <v-date-picker v-model="dateTo" @input="dateMenuTo = false" header-color="primary" :min="dateFrom"></v-date-picker>
                                        </v-menu>
                                        <!-- <v-select :items="couponTypes" label="Type" v-model="type" :disabled="isEdit"></v-select> -->
                                        <v-text-field label="Amount" v-model="amount" :disabled="isEdit" :prepend-icon="prependIcon" :append-icon="appendIcon" @keydown="amtChange($event)"></v-text-field>
                                        <v-checkbox v-model="active" label="Active"></v-checkbox>
                                    </v-form>
                                </v-card>
                            </v-dialog>
                        </v-flex>
                    </v-layout>
                </v-card-title>
                <v-card-text>
                    <v-layout row v-if="allowFilter">
                        <v-flex xs8></v-flex>
                        <v-flex xs4>
                            <v-text-field v-model="search" append-icon="search" label="Filter" single-line hide-details></v-text-field>
                        </v-flex>
                    </v-layout>
                    <v-data-table :headers="this.headers" :items="this.coupons" :search="search" :hide-actions="!allowPagination">
                        <template slot="items" slot-scope="props">
                            <td>{{ props.item.couponCode }}</td>
                            <td>{{ props.item.validFrom }}</td>
                            <td>{{ props.item.validTo }}</td>
                            <td class="text-xs-right">{{ formatMoney(props.item.discountAmount) }}</td>
                            <td class="text-xs-right">{{ formatMoney(props.item.balance) }}</td>
                            <td>
                                <v-checkbox v-model="props.item.active" primary hide-details @change="toggleCoupon(props.item)" :disabled="checkboxStatus"></v-checkbox>
                            </td>
                            <td class="justify-center layout px-0" v-if="isEditable">
                                <v-icon small class="mr-2" @click="editCoupon(props.item)">
                                    edit
                                </v-icon>
                            </td>
                        </template>
                    </v-data-table>
                </v-card-text>
            </v-card>
        </m2m-loading>
    </div>
    `,
    props: {
        editable: Boolean,
        allowFilter: Boolean,
        allowPagination: Boolean
    },
    data: function() {
        return { 
            loading: false,
            dialog: false,
            dialogTitle: 'New Coupon',
            coupons: [],
            search: '',
            couponCode: '',
            validFrom: this.formatDate(new Date().toISOString().substr(0, 10)),
            validTo: this.formatDate(new Date().toISOString().substr(0, 10)),
            couponTypes: ['Amount', 'Percentage'],
            type: '',
            amount: 0,
            isEdit: false,
            dateMenuFrom: false,
            dateMenuTo: false,
            dateFrom: new Date().toISOString().substr(0, 10),
            dateTo: new Date().toISOString().substr(0, 10),
            active: true,
            today: new Date().toISOString().substr(0, 10),
        }
    },
    watch: {
        dateFrom (val) {
            this.validFrom = this.formatDate(this.dateFrom)
        },
        dateTo (val) {
            this.validTo = this.formatDate(this.dateTo)
        }
      },
    computed: {
        headers: function() {
            if(this.isEditable) {
                return [
                    { text: 'Code', value: 'couponCode', width: '30%', sortable: true },
                    { text: 'Valid From', value: 'validFrom', width: '20%', sortable: true },
                    { text: 'Valid To', value: 'validTo', width: '20%', sortable: true },
                    { text: 'Amount', value: 'discountAmount', width: '10%', sortable: true, align: 'right' },
                    { text: 'Balance', value: 'balance', width: '10%', sortable: true, align: 'right' },
                    { text: 'Active', value: 'active', width: '10%', sortable: true },
                ];
            }

            return [
                { text: 'Code', value: 'couponCode', width: '20%', sortable: true },
                { text: 'Valid From', value: 'validFrom', width: '20%', sortable: true },
                { text: 'Valid To', value: 'validTo', width: '20%', sortable: true },
                { text: 'Amount', value: 'discountAmount', width: '10%', sortable: true, align: 'right' },
                { text: 'Balance', value: 'balance', width: '10%', sortable: true, align: 'right' },
                { text: 'Active', value: 'active', width: '10%', sortable: true },
                { text: 'Edit', value: '', width: '10%', sortable: false },
            ];
        },
        isEditable: function() {
            if (this.editable == null || this.editable == undefined)
                return false;
            
            return this.editable;
        },
        prependIcon: function() {
            if (this.type == 'Amount') 
                return 'attach_money';

            return '';
        },
        appendIcon: function() {
            if (this.type == 'Percentage') 
                return 'fas fa-percent';

            return '';
        },
        checkboxStatus: function() {
            return !this.isEditable; 
        },
    },
    created () {
        
    },
    mounted: function() {
        this.load();
    },
    methods: {
        load: function() {
            this.loading = true;
            axios
            .get( app.dataUrl + '?action=couponlist', { } )
                .then( response => { 
                    if( response.data.status ) {
                        this.coupons = response.data.data;
                        this.coupons.forEach(s => {
                            s.active = s.active == 1 ? true : false;
                        });
                    }

                    this.loading = false;
                });
        },
        toTitleCase: function (str) {
            return str.replace(/\-+/g, ' ').replace(/\w\S*/g, function(txt){
                return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
            });
        },
        editCoupon: function(coupon) {
            this.isEdit = true;
            
            this.dialogTitle = 'Edit Coupon';
            this.couponCode = coupon.couponCode;
            this.dateFrom = coupon.validFrom;
            this.dateTo = coupon.validTo;
            this.type = coupon.discountType;
            this.amount = coupon.discountAmount;
            this.active = coupon.active;
            this.dialog = true;
        },
        saveCoupon: function() {

            // Validate user input
            if( !this.validateInput() ) {
                return;
            }

            this.loading = true;

            let formData = {
                couponCode: this.couponCode,
                validFrom: this.dateFrom,
                validTo: this.dateTo,
                type: 'Amount', // this.type,
                amount: this.amount,
                active: this.active,
                isEdit: this.isEdit,
                user: 'rtorres' // cambiar esto por el usuario real
            };

            let axiosOptions = {
                method: 'POST',
                url: app.dataUrl,
                data: { 'form': formData },
                params: {
                    'action': 'admin.newcoupon'
                },
                json: true
            };

            axios(axiosOptions)
            .then( response => { 
                // If everything is ok, go to thankyou page
                if( !response.data.status ) {
                    // show error dialog
                    alert(response.data.error );
                    return;
                }
                else if(response.data.status == 'false' ) {
                    // show error dialog
                    alert(response.data.message );
                    return;
                }

                // Add/Edit the new stylist to the table
                if ( this.isEdit ) {
                    let editCoupon = this.coupons.find(coupon => {
                        return coupon.couponCode == formData.couponCode;
                    });

                    editCoupon.validFrom = formData.validFrom;
                    editCoupon.validTo = formData.validTo;
                    editCoupon.active = formData.active;
                }
                else {
                    this.coupons.push({ 
                        couponCode: formData.couponCode, 
                        createdDate: formData.createdDate, 
                        createdBy: formData.createdBy,
                        validFrom: formData.validFrom,
                        validTo: formData.validTo,
                        discountAmount: formData.amount,
                        discountType: formData.type,
                        balance: formData.balance,
                        active: formData.active 
                    });
                }

                this.closeDialog();
                this.loading = false;
            })
            .catch(function (error) {
                console.log(error);
                this.loading = false;
            });
        },
        toggleCoupon: function(coupon) {
            let formData = {
                couponCode: coupon.couponCode,
                active: coupon.active
            };

            let axiosOptions = {
                method: 'POST',
                url: app.dataUrl,
                data: { 'form': formData },
                params: {
                    'action': 'admin.togglecoupon'
                },
                json: true
            };

            axios(axiosOptions)
            .then( response => { 
                // If everything is ok, go to thankyou page
                if( !response.data.status ) {
                    // show error dialog
                    alert(response.data.error );
                    return;
                }
                else if(response.data.status == 'false' ) {
                    // show error dialog
                    alert(response.data.message );
                    return;
                }


                let editCoupon = this.stylists.find(c => {
                    return c.couponCode == formData.couponCode;
                });

                editCoupon.active = formData.active;
            })
            .catch(function (error) {
                console.log(error);
            });
        },
        closeDialog: function() {
            this.dialog = false;
            
            this.dialogTitle = 'New Coupon';
            this.couponCode = '';
            this.validFrom = this.validTo = this.formatDate(new Date().toISOString().substr(0, 10));
            this.type = '';
            this.amount = 0;
            this.active = true;
            this.isEdit = false;
        },
        formatDate (date) {
            if (!date) return null
    
            const [year, month, day] = date.split('-')
            return `${month}/${day}/${year}`
        },
        formatMoney: function(n, c, d, t) {
            var c = isNaN(c = Math.abs(c)) ? 2 : c,
              d = d == undefined ? "." : d,
              t = t == undefined ? "," : t,
              s = n < 0 ? "-" : "",
              i = String(parseInt(n = Math.abs(Number(n) || 0).toFixed(c))),
              j = (j = i.length) > 3 ? j % 3 : 0;
          
            return '$' + s + (j ? i.substr(0, j) + t : "") + i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + t) + (c ? d + Math.abs(n - i).toFixed(c).slice(2) : "");
        },
        amtChange: function(e, item) {
            // Allow: backspace, delete, tab, escape, enter and .
            if ([46, 8, 9, 27, 13, 110, 190].indexOf(e.keyCode) !== -1 ||
                // Allow: Ctrl/cmd+A
            (e.keyCode == 65 && (e.ctrlKey === true || e.metaKey === true)) ||
                // Allow: Ctrl/cmd+C
            (e.keyCode == 67 && (e.ctrlKey === true || e.metaKey === true)) ||
                // Allow: Ctrl/cmd+X
            (e.keyCode == 88 && (e.ctrlKey === true || e.metaKey === true)) ||
                // Allow: home, end, left, right
            (e.keyCode >= 35 && e.keyCode <= 39)) {
                // let it happen, don't do anything
                return;
            }

            // Ensure that it is a number and stop the keypress
            if ((e.shiftKey || (e.keyCode < 48 || e.keyCode > 57)) && (e.keyCode < 96 || e.keyCode > 105)) {
                e.preventDefault();
            }
        },
        validateInput: function() {
            if(this.couponCode == undefined || this.couponCode == null || this.couponCode.length == 0) {
                alert('You must enter a valid coupon code.')
                return false;
            }

            // if ( this.type == undefined || this.type == null || (this.type != 'Amount' && this.type != 'Percentage') ) {
            //     alert('You must select a coupon type.');
            //     return false;
            // }
            
            if( !this.validateCurrency(this.amount) ) {
                alert('You must enter a valid amount.');
                return false;
            }

            return true;
        },
        validateCurrency: function(amt) {
            var regex  = /^[1-9]\d*(((,\d{3}){1})?(\.\d{0,2})?)$/;
            return regex.test(amt);
        }
    }
});