Vue.component('m2m-admin-date-picker', {
    template: `
    <div>
        <v-layout row wrap>
            <v-flex xs12>
                <v-btn-toggle v-model="dateType" mandatory @change="changeDateType">
                    <v-btn flat value="single">
                        Single Date
                    </v-btn>
                    <v-btn flat value="range">
                        Date Range
                    </v-btn>
                </v-btn-toggle>
            </v-flex>
            <v-flex xs12>
                <br>
            </v-flex>
            <v-flex xs6>
                <v-menu :close-on-content-click="false" v-model="dateMenu" :nudge-right="40" lazy transition="scale-transition" offset-y full-width min-width="290px">
                    <v-text-field slot="activator" v-model="dateFormatted" :label="dateLabel" prepend-icon="event" @input="changeDate('first')" readonly></v-text-field>
                    <v-date-picker v-model="date" @input="dateMenu = false" header-color="primary" :type="type ? type : 'date'"></v-date-picker>
                </v-menu>
            </v-flex>
            <v-flex xs6 v-if="dateType == 'range'">
                <v-menu :close-on-content-click="false" v-model="dateMenu2" :nudge-right="40" lazy transition="scale-transition" offset-y full-width min-width="290px">
                    <v-text-field slot="activator" v-model="dateFormatted2" :label="date2Label" prepend-icon="event" @input="changeDate('second')" readonly></v-text-field>
                    <v-date-picker v-model="date2" @input="dateMenu2 = false" header-color="primary" :type="type ? type : 'date'"></v-date-picker>
                </v-menu>
            </v-flex>
        </v-layout>
    </div>
`,
    props: {
        type: String,
    }, 
    data() {
        return {
            dateType: 'single',
            dateMenu: false,
            date: this.type == 'month' ? new Date().toISOString().substr(0, 7) : new Date().toISOString().substr(0, 10),
            dateFormatted: this.formatDate(new Date().toISOString().substr(0, 10)),
            dateMenu2: false,
            date2: this.type == 'month' ? new Date().toISOString().substr(0, 7) : new Date().toISOString().substr(0, 10),
            dateFormatted2: this.formatDate(new Date().toISOString().substr(0, 10)),
            dateLabel: 'Select Date',
            date2Label: 'To Date'
        }
    },
    computed: {
        selectedDate: function() {
            if( this.type == 'month') {
                if(this.dateType == 'single')
                    return this.parseDate(this.formatParamDate(this.date, 'first')) + ';' + this.parseDate(this.formatParamDate(this.date,'second'));
                else if(this.dateType == 'range')
                    return this.parseDate(this.formatParamDate(this.date, 'first')) + ';' + this.parseDate(this.formatParamDate(this.date2,'second'));
            }
            else {
                if(this.dateType == 'single')
                    return this.date;
                else if(this.dateType == 'range')
                    return this.date + ';' + this.date2;
            }
        }
      },
  
      watch: {
        date (val) {
            this.changeDate('first');
            this.dateFormatted = this.formatParamDate(this.date, 'first');
        },
        date2 (val) {
            this.changeDate('second');
            this.dateFormatted2 = this.formatParamDate(this.date2, 'second');
        }
      },
    mounted: function() {
        this.load();
    },
    methods: {
        load: function() {
            this.$emit('load', this.selectedDate);
        },
        formatDate (date) {
            if (!date) return null

            const [year, month, day] = date.split('-')

            if(this.type == 'month')
                return `${month}/${year}`;   

            return `${month}/${day}/${year}`;
        },
        formatParamDate (date, whichDate) {
            if (!date) return null;

            const [year, month, day] = date.split('-');

            if(this.type == 'month' && whichDate == 'first')
                return `${month}/01/${year}`;
            else if (this.type == 'month' && whichDate == 'second')
                return `${month}/${this.lastday(year,month)}/${year}`;   

            return `${month}/${day}/${year}`;
        },
        parseDate (date) {
            if (!date) return null

            const [month, day, year] = date.split('/')
            return `${year}-${month.padStart(2, '0')}-${day.padStart(2, '0')}`
        },
        lastday: function(y, m){
            return  new Date(y, m, 0).getDate();
        },
        changeDateType: function() {
            if(this.dateType == 'single') {
                this.dateLabel = 'Select Date';
                this.date2Label = 'To Date';
            }
            else if (this.dateType == 'range'){
                this.dateLabel = 'From Date';
                this.date2Label = 'To Date';
            }
            this.$emit('dateChanged', this.selectedDate);
        },
        changeDate: function(whichDate) {
            if(whichDate == 'first')
                this.$emit('dateChanged', this.selectedDate);
            else if( this.dateType == 'range' )
                this.$emit('dateChanged', this.selectedDate);
        }
    }
})