Vue.component('m2m-admin-drawer', {
    template: `
        <v-navigation-drawer v-model="drawer" :mini-variant.sync="mini" fixed app @click.stop="drawer = !drawer" dark>
            <v-toolbar flat class="transparent">
                <v-list class="pa-0">
                    <v-list-tile avatar>
                        <v-list-tile-avatar>
                            <img :src="this.logo" alt="logo" style="width:25px;">
                        </v-list-tile-avatar>
                
                        <v-list-tile-content>
                            <v-list-tile-title>M2M Admin Panel <span class="caption">v1.0</span></v-list-tile-title>
                        </v-list-tile-content>
                
                        <v-list-tile-action>
                            <v-btn icon @click.stop="mini = !mini">
                                <v-icon>chevron_left</v-icon>
                            </v-btn>
                        </v-list-tile-action>
                    </v-list-tile>
                </v-list>
            </v-toolbar>
            <v-list dense>
                <v-divider></v-divider>
                
                <v-list-tile @click="openItem('/')">
                    <v-list-tile-action>
                        <v-icon>dashboard</v-icon>
                    </v-list-tile-action>
                    <v-list-tile-content>
                        <v-list-tile-title>Dashboard</v-list-tile-title>
                    </v-list-tile-content>
                </v-list-tile>
                
                <v-list-tile @click="openItem('/orders')" v-if="privileges.mngOdr == 1">
                    <v-list-tile-action>
                        <v-icon>list</v-icon>
                    </v-list-tile-action>
                    <v-list-tile-content>
                        <v-list-tile-title>Orders</v-list-tile-title>
                    </v-list-tile-content>
                </v-list-tile>
                
                <v-list-group prepend-icon="bar_chart" no-action v-if="privileges.vwRpt == 1">
                    <v-list-tile slot="activator">
                        <v-list-tile-title>Reports</v-list-tile-title>
                    </v-list-tile>
               
                    <v-list-tile v-for="(rpt, i) in reports" :key="i" @click="openReport(rpt)">
                        <v-list-tile-title>{{ rpt.name }}</v-list-tile-title>
                        <v-list-tile-action>
                            <v-icon>{{ rpt.icon }}</v-icon>
                        </v-list-tile-action>
                    </v-list-tile>
                </v-list-group>
                    
            </v-list>
            <v-footer fixed inset style="height:auto;" v-if="isConfigurationVisible">
                <v-layout row>
                    <v-flex xs12>
                        <v-list dense class="pb-0 pt-0">
                            <v-list-tile fixed @click="openItem('/configuration')">
                                <v-list-tile-action>
                                    <v-icon>settings</v-icon>
                                </v-list-tile-action>
                                <v-list-tile-content>
                                    <v-list-tile-title>Configuration</v-list-tile-title>
                                </v-list-tile-content>
                            </v-list-tile>
                        </v-list>
                    </v-flex>
                </v-layout>
            </v-footer>
        </v-navigation-drawer>
`,
    props: ['logo','router','privileges'],
    data() {
        return {
            drawer: true,
            mini: false,
            reports: [
                { name: 'Sales by Month', icon: '', rpt: '/rpt/salesbymonth' },
                { name: 'Sales by Stylist', icon: '', rpt: '/rpt/salesbyrep' },
                { name: 'Sales by Item', icon: '', rpt: '/rpt/salesbyitem' },
                { name: 'Sales by Store', icon: '', rpt: '/rpt/salesbystore' },
                { name: 'Orders by Status', icon: '', rpt: '/rpt/ordersbystatus' },
                { name: 'Journal', icon: '', rpt: '/rpt/journal' },
                { name: 'Cuadre', icon: '', rpt: '/rpt/cuadre' },
            ],
        }
    },
    mounted() {
    },
    computed: {
        isConfigurationVisible: function() {
            if( this.privileges.mngUsr == 0 && 
                this.privileges.mngStl == 0 &&
                this.privileges.mngRef == 0 &&
                this.privileges.mngCpn == 0 &&
                this.privileges.vwLog == 0 )
                return false;
            else 
                return true;
        }
    },
    methods: {
        openReport: function(rpt) {
            this.$router.push(rpt.rpt);
        },
        openItem: function(route) {
            this.$router.push(route);
        }
    }
})