Vue.component("m2m-item-attributes", {
    template: `
    <div>
        <v-list two-line subheader>
            <v-subheader>{{ this.title }}</v-subheader>

            <!-- Modifications -->
            <v-list-tile avatar v-for="mod in items" :key="mod.categoryId" v-if="type == 'modification'">
                <v-list-tile-avatar color="white">
                    <img :src="mod.optionImage">
                </v-list-tile-avatar>
                <v-list-tile-content>
                    <v-list-tile-title class="caption">{{ toTitleCase(mod.categoryName) }}</v-list-tile-title>
                    <v-list-tile-sub-title class="caption">{{ toTitleCase(mod.optionName) }}</v-list-tile-sub-title>
                    <v-list-tile-sub-title class="caption" v-if="item.isCouture == 1">{{ mod.coutureDescription }}</v-list-tile-sub-title>
                </v-list-tile-content>
                <v-list-tile-action v-if="editable">
                    <v-icon small @click="openEditDialog(mod)">
                        edit
                    </v-icon>
                </v-list-tile-action>
            </v-list-tile>

            <!-- Fabrics -->
            <v-list-tile avatar v-for="fab in items" :key="fab.categoryId" v-if="type == 'fabric'">
                <v-list-tile-avatar>
                    <img :src="fab.optionImage">
                </v-list-tile-avatar>
                <v-list-tile-content>
                    <v-list-tile-title class="caption">{{
                        toTitleCase(fab.categoryName) }}</v-list-tile-title>
                    <v-list-tile-sub-title class="caption">{{
                        toTitleCase(fab.optionName) }}</v-list-tile-sub-title>
                </v-list-tile-content>
                <v-list-tile-action v-if="editable">
                    <v-icon small @click="openEditDialog(fab)">
                        edit
                    </v-icon>
                </v-list-tile-action>
            </v-list-tile>
        </v-list>

        <!-- Edit Dialog -->
        <v-dialog v-model="dialog" width="500" persistent>
            <v-card>
                <v-card-title v-if="this.editItem != undefined">
                    <span class="headline" v-if="type == 'modification'">Edit the {{ toTitleCase(this.editItem.categoryName) }} option</span>
                    <span class="headline" v-if="type == 'fabric'">Choose another fabric for the {{ toTitleCase(this.editItem.categoryName) }}</span>
                </v-card-title>
                <v-card-text>
                    <v-select :items="updateOptions" label="New Value" v-model="newOptionId" item-text="categoryName"
                    item-value="categoryId">
                        <template slot="selection" slot-scope="data">
                            <v-flex xs2>
                                <v-avatar size="25px">
                                    <img :src="data.item.image_url"/>
                                </v-avatar>
                            </v-flex>
                            <v-flex class='ml-1'>
                                {{ data.item.categoryName }}
                            </v-flex>
                        </template>
                        <template slot="item" slot-scope="data">
                            <v-list-tile-avatar>
                                <img :src="data.item.image_url" />
                            </v-list-tile-avatar>
                            <v-list-tile-content>
                                <v-list-tile-title v-html="data.item.categoryName"></v-list-tile-title>
                            </v-list-tile-content>
                        </template>
                    </v-select>

                    <v-textarea name="updateNote" label="Note" hint="Why the update is being done?" v-model="updateReason"></v-textarea>
                </v-card-text>

                <v-divider></v-divider>

                <v-card-actions>
                    <v-spacer></v-spacer>
                    <v-btn flat @click="dialog = false">
                        Cancel
                    </v-btn>
                    <v-btn color="primary" flat @click="updateAttribute">
                        UPDATE
                    </v-btn>
                </v-card-actions>
            </v-card>
        </v-dialog>
    </div>
    `,
    props: {
        type: String,
        editable: Boolean,
        orderId: String,
        item: Object,
        title: String,
        items: Array,
        productId: String,
    },
    data: function() {
        return { 
            dialog: false,
            editItem: undefined,
            updateOptions: [],
            newOptionId: '',
            updateReason: '',
        }
    },
    computed: {
        
    },
    created () {
        
    },
    mounted: function() {
        
    },
    methods: {
        toTitleCase: function (str) {
            return str.replace(/\-+/g, ' ').replace(/\w\S*/g, function(txt){
                return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
            });
        },
        openEditDialog: function(item) {
            this.editItem = item;
            this.dialog = true;

            // Load options
            let action = '?action=modopt&c=' + item.categoryId;
            if( this.type == 'fabric' )
                action = '?action=fabmod&c=' + item.categoryId + '&pid=' + this.productId;

            axios
            .get( app.dataUrl + action, { })
            .then( response => { 
                if(response.data.status ) {
                    this.updateOptions = [];
                    response.data.data.forEach(opt => {
                        if( this.type == 'modification')
                            this.updateOptions.push({ categoryName: opt.name, categoryId: opt.mod_option_id, image_url: opt.image_url });
                        else if( this.type == 'fabric' )
                            this.updateOptions.push({ categoryName: opt.name, categoryId: opt.fabric_id, image_url: opt.image_url });
                    });
                }
                
            })
            .catch(function (error) {
                console.log(error);
                this.loading = false;
            });
        },
        updateAttribute: function() {
            let newOption = this.updateOptions.find(o => {
                return o.categoryId == this.newOptionId;
            });

            if (newOption == undefined || this.updateReason == '') {
                alert('Both fields are required.');
                return;
            }

            let formData = {
                orderId: this.orderId,
                itemName: this.item.productName,
                itemId: this.item.itemId,
                type: this.type,
                categoryName: this.toTitleCase(this.editItem.categoryName),
                categoryId: this.editItem.categoryId,
                fromValue: {
                    optionName: this.editItem.optionName,
                    optionNameFormatted: this.toTitleCase(this.editItem.optionName),
                    optionId: this.editItem.optionId,
                    imageUrl: this.editItem.optionImage
                },
                toValue: {
                    optionName: newOption.categoryName,
                    optionNameFormatted: this.toTitleCase(newOption.categoryName),
                    optionId: newOption.categoryId,
                    imageUrl: newOption.image_url
                },
                note: this.updateReason,
                user: 'rtorres' // cambiar esto por el usuario real
            };

            let axiosOptions = {
                method: 'POST',
                url: app.dataUrl,
                data: { 'form': formData },
                params: {
                    'action': 'admin.updateattribute'
                },
                json: true
            };

            axios(axiosOptions)
            .then( response => { 
                // If everything is ok, go to thankyou page
                if( !response.data.status ) {
                    // show error dialog
                    alert(response.data.error );
                    return;
                }
                else if(response.data.status == 'false' ) {
                    // show error dialog
                    alert(response.data.message );
                    return;
                }

                // Update image and value of the changed attribute
                this.editItem.optionName = newOption.categoryName;
                this.editItem.optionImage = newOption.image_url;

                let updatedValues = {
                    note: response.data.data.note,
                    history: response.data.data.historyItem
                };
                this.$emit('update', updatedValues);

                this.dialog = false;
                this.updateReason = '';
            })
            .catch(function (error) {
                console.log(error);
            });
        },
    }
});