Vue.component("m2m-payment-processor", {
    template: `
    <div>
        <v-card>
            <v-card-title class="headline" v-if="title.length > 0">
                <v-icon medium v-if="enableIcon">payment</v-icon> {{ this.title }}
            </v-card-title>
            <v-card-text>
                <v-form ref="form" v-model="valid">
                    <v-layout row wrap fill-height align-center>
                        <v-flex xs4 class="mb-3">
                            <p>Payment Method</p>
                        </v-flex>
                        <v-flex xs8 class="mb-3">
                            <v-select :items="paymentMethods" v-model="paymentMethod" label="" @change="updatePaymentMethod"></v-select>
                        </v-flex>
                        <v-flex xs12>
                            <v-layout row>
                                <v-flex xs6>
                                    <v-form v-model="valid">
                                        <v-select v-model="paymentSelect" :items="paymentOptions"
                                            :rules="[v => !!v || 'A payment Option is required']" label="Payment Options"
                                            @change="updatePaymentAmount()" required></v-select>
                                    </v-form>
                                </v-flex>
                                <v-flex xs5 offset-xs1 class="text-xs-right">
                                    <v-form v-model="valid">
                                        <v-text-field v-model="paymentAmount" :rules="paymentAmountRules"
                                            label="Payment Amount" :readonly="paymentAmountDisable"
                                            prefix="$" @keydown="amountChange($event)"></v-text-field>
                                    </v-form>
                                </v-flex>
                            </v-layout>
                        </v-flex>
                        <v-flex xs12 v-if="this.paymentMethod == 'Stripe'">
                            <div id="card-element"></div>
                        </v-flex>
                        <v-flex xs12 v-if="this.paymentMethod != 'Stripe'">
                            <v-form v-model="valid">
                                <v-text-field v-model="posConfirmationNumber" :rules="posConfirmationNumberRules"
                                    label="Confirmation Number"></v-text-field>
                            </v-form>
                        </v-flex>
                        <v-flex xs12>
                            <div id="card-errors" role="alert" style="margin-top:10px;color:red;"></div>
                        </v-flex>
                    </v-layout>
                </v-form>
            </v-card-text>

            <v-divider v-if="isDialog"></v-divider>

            <v-card-actions v-if="isDialog">
                <v-spacer></v-spacer>
                <v-btn flat @click="closeDialog">
                    Cancel
                </v-btn>
                <v-btn color="primary" flat @click="processPayment" :disabled="isProcessPaymentDisabled">
                    Process Payment
                </v-btn>
            </v-card-actions>
        </v-card>
    </div>`,
    props: {
        title: String,
        enableIcon: {
            type: Boolean,
            default: true
        },
        total: Number,
        isDialog: {
            type: Boolean,
            default: true
        },
        orderId: String,
        defaultMethod: {
            type: String,
            default: ''
        },
        allowedMethods: {
            type: Array,
            default: function () { return ['Amex','Debit','Cash','Discover','MasterCard','Stripe','Visa']; }
        },
        authToken: {
            type: String,
            default: ''
        }
    },
    data: function() {
        return { 
            elements: undefined, 
            card: undefined,
            valid: false,
            availablePaymentMethods: [
                { text: 'American Express', value: 'Amex' },
                { text: 'ATH / Debit', value: 'Debit' },
                { text: 'Cash', value: 'Cash' }, 
                { text: 'Discover', value: 'Discover' },
                { text: 'Master Card', value: 'MasterCard' },
                { text: 'Online', value: 'Stripe' },
                { text: 'Visa', value: 'Visa' }
            ],
            paymentMethod: this.defaultMethod,
            paymentSelect: 'Total Amount',
            paymentOptions: [
                'Total Amount',
                '50%',
                'Other',
            ],
            watchHandOptions: [
                'Left',
                'Right',
                'None'
            ],
            paymentAmount: this.total,
            paymentAmountRules: [
                v => this.tryParseInt(this.formatPaymentAmount(v).toString(), false) || 'Payment Amount must be valid',
                v => this.formatPaymentAmount(v) <= this.formatPaymentAmount(this.total + 0.01) || 'Payment Amount cannot be greated than order total',
            ],
            posConfirmationNumber: '',
            posConfirmationNumberRules: [
                v => !!v || 'Payment confirmation number is required'
            ],
            paymentAmountDisable: true,
            token: null,
            formHasError: false,
            processing: false,
        }
    },
    computed: {
        form: function () {
            return {
                orderId: this.orderId,
                paymentMethod: this.paymentMethod,
                paymentAmount: this.paymentAmount,
                paymentToken: this.token,
                paymentConfirmationNumber: this.posConfirmationNumber,
            }
        },
        paymentMethods: function() {
            let pMthds = [];
            this.allowedMethods.forEach(m => {
                let pm = this.availablePaymentMethods.find(function(am) {
                    return am.value == m;
                });

                if ( pm != null)
                    pMthds.push(pm);
            });

            return pMthds;
        },
        isProcessPaymentDisabled: function() {
            return this.paymentAmount < 1 || this.processing;
        },
    },
    created () {
        
    },
    mounted: function() {
        this.load();

        // load Stripe script
        let stripeScript = document.createElement('script');
        stripeScript.setAttribute('src', 'https://js.stripe.com/v3/');
        document.body.appendChild(stripeScript);

        let style = {
            base: {
              // Add your base input styles here. For example:
              fontSize: '18px',
              color: "#000",
              fontFamily: 'Roboto,sans-serif'
            }
        };

        setTimeout(() => { 
            this.stripe = Stripe(`pk_test_o09PtlJcY7qLjqxmFBzAwVdp`); // Development
            // this.stripe = Stripe(`pk_live_tQ9N5caSTachhcYvcH3vyCll`); // Live
            this.elements = this.stripe.elements();
            this.card = this.elements.create('card', { style: style } );

            if ( this.paymentMethod == 'Stripe' )
                this.card.mount('#card-element');

            this.card.addEventListener('change', function(event) {
                var displayError = document.getElementById('card-errors');
                if (event.error) {
                    displayError.textContent = event.error.message;
                } else {
                    displayError.textContent = '';
                }
            });
        }, 1000);

        this.paymentAmount = this.formatMoneyWithoutSymbol( this.total );
    },
    methods: {
        load: function() {
            if ( this.allowedMethods.length == 1 )
                this.paymentMethod = this.allowedMethods[0];
        },
        toTitleCase: function (str) {
            return str.replace(/\-+/g, ' ').replace(/\w\S*/g, function(txt){
                return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
            });
        },
        updatePaymentMethod: function() {
            if( this.paymentMethod == 'Stripe' ) {
                setTimeout(() => { 
                    this.card.mount('#card-element');
                }, 500);
            }
            else 
                this.card.unmount('#card-element');
        },
        formatPaymentAmount: function(val) {
            if ( val == undefined)
                return 0;
                
            return parseFloat(val.toString().split(',').join(''));
        },
        updatePaymentAmount: function() {
            if(this.paymentSelect == '25%') {
                this.paymentAmount = this.formatMoneyWithoutSymbol( this.total * 0.25 );
                this.paymentAmountDisable = true;
            }
            else if(this.paymentSelect == '50%') {
                this.paymentAmount = this.formatMoneyWithoutSymbol( this.total * 0.5 );
                this.paymentAmountDisable = true;
            }
            else if(this.paymentSelect == '75%') {
                this.paymentAmount = this.formatMoneyWithoutSymbol( this.total * 0.75 );
                this.paymentAmountDisable = true;
            }
            else if(this.paymentSelect == 'Total Amount') {
                this.paymentAmount = this.formatMoneyWithoutSymbol( this.total );
                this.paymentAmountDisable = true;
            }
            else if(this.paymentSelect == 'Other') {
                this.paymentAmount = 0;
                this.paymentAmountDisable = false;
            }
            else if(this.paymentSelect == 'No payment') {
                this.paymentAmount = 0;
                this.paymentAmountDisable = true;
            }
        },
        tryParseInt: function(str, defaultValue) {
            var retValue = defaultValue;
            if(str !== null) {
                if(str.length > 0) {
                    if (!isNaN(str)) {
                        // retValue = parseInt(str);
                        retValue = true;
                    }
                }
            }
            return retValue;
        },
        formatMoneyWithoutSymbol: function(n, c, d, t) {
            var c = isNaN(c = Math.abs(c)) ? 2 : c,
              d = d == undefined ? "." : d,
              t = t == undefined ? "," : t,
              s = n < 0 ? "-" : "",
              i = String(parseInt(n = Math.abs(Number(n) || 0).toFixed(c))),
              j = (j = i.length) > 3 ? j % 3 : 0;
          
            return s + (j ? i.substr(0, j) + t : "") + i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + t) + (c ? d + Math.abs(n - i).toFixed(c).slice(2) : "");
        },
        closeDialog: function() {
            this.paymentSelect = 'Total Amount'
            this.paymentMethod = '';
            this.posConfirmationNumber = '';

            this.$emit('close');
        },
        processPayment: function() {
            // Validate input information
            this.validateForm();
            if ( this.formHasError ) {
                alert('There is an error with the information provided. Make sure you have a valid payment amount.');
                return;
            }

            this.processing = true;
            let formData = this.form;

            if (formData.paymentMethod != 'Stripe' ) {
                let axiosOptions = {
                    method: 'POST',
                    url: app.dataUrl,
                    data: { 'form': formData },
                    params: {
                        'action': this.authToken.length == 0 ? 'regpaymentnoauth' : 'regpayment'
                    },
                    headers: { 'Authorization' : this.authToken.length == 0 ? app.authKey : app.authKey + ',Bearer ' + this.authToken },
                    json: true
                };

                axios(axiosOptions)
                .then( response => { 
                    // If everything is ok, go to thankyou page
                    if( response.data.status == 'error' ) {
                        // Codigo para desplegar error
                        return;
                    }
                    else if ( response.data.status == 'Payment Processed' ) {
                        this.$emit('processed', response.data.payment);
                        this.cleanForm();
                        return;
                    }
                    this.processing = false;
                })
                .catch(function (error) {
                    console.log(error);
                    this.processing = false;
                });
            }
            else if (formData.paymentMethod == 'Stripe') {
                // If is valid, create Stripe token
                let tkn = this.authToken;
                let frm = this;
                this.stripe.createToken(this.card).then(function(result) {
                    if (result.error) {
                        // Inform the customer that there was an error.
                        var errorElement = document.getElementById('card-errors');
                        errorElement.textContent = result.error.message;
                        this.processing = false;
                    } else {
                        this.token = result.token.id;
                        formData.paymentToken = result.token.id;
                        // Call de M2M API to charge the card and create the order.
                        let axiosOptions = {
                            method: 'POST',
                            url: app.dataUrl,
                            data: { 'form': formData },
                            params: {
                                'action': tkn.length == 0 ? 'regpaymentnoauth' : 'regpayment'
                            },
                            headers: { 
                                'Authorization' : (tkn.length == 0 ? app.authKey : app.authKey + ',Bearer ' + tkn) 
                            },
                            json: true
                        };
                        
                        axios(axiosOptions)
                        .then( response => { 
                            // If everything is ok, go to thankyou page
                            if( response.data.status == 'error' ) {
                                // Codigo para desplegar error
                                return;
                            }
                            else if ( response.data.status == 'Payment Processed' ) {
                                frm.$emit('processed', response.data.payment);
                                frm.cleanForm();
                                return;
                            }
                            this.processing = false;
                        })
                        .catch(function (error) {
                            console.log(error);
                            this.processing = false;
                        });
                    }
                });
            }
        },
        validateForm: function() {
            let form = this.$refs.form.validate();

            if( form && this.paymentAmount > 0 )
                this.formHasError = false;
            else
                this.formHasError = true;
        },
        amountChange: function(e, item) {
            // Allow: backspace, delete, tab, escape, enter and .
            if ($.inArray(e.keyCode, [46, 8, 9, 27, 13, 110, 190]) !== -1 ||
                // Allow: Ctrl/cmd+A
            (e.keyCode == 65 && (e.ctrlKey === true || e.metaKey === true)) ||
                // Allow: Ctrl/cmd+C
            (e.keyCode == 67 && (e.ctrlKey === true || e.metaKey === true)) ||
                // Allow: Ctrl/cmd+X
            (e.keyCode == 88 && (e.ctrlKey === true || e.metaKey === true)) ||
                // Allow: home, end, left, right
            (e.keyCode >= 35 && e.keyCode <= 39)) {
                // let it happen, don't do anything
                return;
            }

            // Ensure that it is a number and stop the keypress
            if ((e.shiftKey || (e.keyCode < 48 || e.keyCode > 57)) && (e.keyCode < 96 || e.keyCode > 105)) {
                e.preventDefault();
            }
        },
        cleanForm: function() {
            this.paymentAmount = 0;
            this.posConfirmationNumber = '';
            this.paymentMethod = '';
        },
    }
});