var configuration = Vue.component("m2m-admin-configuration", {
    template: `
    <v-app id="configuration">
        <v-layout row>
            <v-flex xs6 sm12 v-if="privileges.mngUsr == 1 || privileges.mngCpn == 1">
                <v-layout column>
                    <!-- Users -->
                    <v-flex v-if="privileges.mngUsr == 1">
                        <m2m-user-list :editable="true" :allow-filter="true" :allow-pagination="true"></m2m-user-list>
                    </v-flex>

                    <!-- Coupons -->
                    <v-flex class="mt-2" v-if="privileges.mngCpn == 1">
                        <m2m-coupon-list :editable="true" :allow-filter="true" :allow-pagination="true"></m2m-coupon-list>
                    </v-flex>
                </v-layout>
            </v-flex>
            <v-flex xs6 sm12 class="ml-3" v-if="privileges.mngStl == 1 || privileges.mngRef == 1">
                <v-layout column>
                    <!-- Referrals -->
                    <v-flex v-if="privileges.mngStl == 1">
                        <m2m-rep-list :editable="true" type="Stylist" :allow-filter="true" :allow-pagination="true"></m2m-rep-list>
                    </v-flex>

                    <!-- Referrals -->
                    <v-flex class="mt-2" v-if="privileges.mngRef == 1">
                        <m2m-rep-list :editable="true" type="Referral" :allow-filter="true" :allow-pagination="true"></m2m-rep-list>
                    </v-flex>
                </v-layout>
            </v-flex>
        </v-layout>
        <v-layout row fill-height class="mt-3" v-if="privileges.vwLog == 1">
            <v-flex xs12>
                <v-card flat>
                    <v-card-title primary-title>
                        <v-layout row>
                            <v-flex xs8>
                                <div class="title">Log</div>
                            </v-flex>
                        </v-layout>
                    </v-card-title>
                    <v-card-text>
                        <v-layout row>
                            <v-flex xs8></v-flex>
                            <v-flex xs4>
                                <v-text-field v-model="logSearch" append-icon="search" label="Filter" single-line hide-details></v-text-field>
                            </v-flex>
                        </v-layout>
                        <v-data-table :headers="this.logHeaders" :items="this.logItems" :search="this.logSearch" item-key="[logDate,action]" :rows-per-page-items="this.paginationOptions">
                            <template slot="items" slot-scope="props">
                                <td>{{ props.item.logDate }}</td>
                                <td>{{ props.item.userName }}</td>
                                <td>{{ props.item.orderId }}</td>
                                <td>{{ props.item.action }}</td>
                                <td>{{ props.item.message }}</td>
                                <td>{{ props.item.ip }}</td>
                            </template>
                        </v-data-table>
                    </v-card-text>
                </v-card>
            </v-flex>
        </v-layout>
    </v-app>
    `,
    data: function() {
        return { 
            logHeaders: [
                { text: 'Date', value: 'logDate', sortable: true },
                { text: 'User', value: 'userName', sortable: true },
                { text: 'Order ID', value: 'orderId', sortable: false },
                { text: 'Action', value: 'action', sortable: false },
                { text: 'Message', value: 'message', sortable: false },
                { text: 'IP', value: 'ip', sortable: false },
            ],
            logItems: [],
            logSearch: '',
            paginationOptions: [ 25, 50, { "text": "$vuetify.dataIterator.rowsPerPageAll", "value": -1 } ],
        }
    },
    computed: {
        privileges: function() {
            return app.store.userPrivileges;
        }
    },
    created () {
        serverBus.$emit('changePageTitle', 'Configuration');
        this.init();
    },
    mounted: function() {
        
    },
    methods: {
        init: function() {
            axios
            .get( app.dataUrl + '?action=log', { } )
                .then( response => { 
                    if( response.data.status ) {
                        this.logItems = response.data.data;
                    }

                    this.loading = false;
                });
        },
        toTitleCase: function (str) {
            return str.replace(/\-+/g, ' ').replace(/\w\S*/g, function(txt){
                return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
            });
        },
    }
});