var product = Vue.component('product-selection', {
    props: ['item'],
    template: `
    <v-app>
        <m2m-loading v-if="loading"></m2m-loading>
        <v-container fluid fill-width>
            <v-layout row wrap fluid>
                <product-option v-for="item in productTypes" v-bind:type="item" v-bind:key="item.id"></product-option>
            </v-layout>
        </v-container>
        <div :class="item == undefined ? 'hidden' : ''">
            <router-link to="/designer"><v-btn color="red" dark large fixed bottom right>Design your {{ item == undefined ? '' : item.name }}</v-btn></router-link>
        </div>
    </v-app>`,
    created () {
        this.loadProducts();

        // Using the service bus
        serverBus.$on('typeSelected', (type) => {
            this.item = type;
        });
    },
    data: function () {
        return {
            loading: false,
            productTypes: null
        }
    },
    watch: {
        // call again the method if the route changes
        '$route': 'loadProducts'
    },
    methods: {
        loadProducts: function () {
            this.loading = true;
            axios
                .get( app.dataUrl + '?action=prodtype', { headers: { Authorization: app.authKey } })
                .then( response => { 
                    this.productTypes = response.data.data;
                    app.productTypes = response.data.data;

                    for ( let i = 0; i < app.productTypes.length; i++ ) {
                        if ( app.productTypes[i].active == 1 || app.productTypes[i].active == "1")
                            app.productTypes[i].active = true;
                        else
                            app.productTypes[i].active = false;
                    }
                    
                    app.pageStack.splice(1);
                    app.pageStack[0].disabled = false;
                    app.pageStack.push( {
                        text: 'Products',
                        disabled: true,
                        href: '#/products'
                    });
                    this.loading = false;
                });
        }
    }
});