Vue.component('m2m-admin-login', {
    template: `
    <div>
        <v-dialog v-model="show" width="500" persistent fullscreen dark hide-overlay transition="dialog-bottom-transition">
            <v-card dark>
                <v-toolbar dark color="primary">
                    <v-toolbar-title>Made To Measure - Admin Area</v-toolbar-title>
                    <v-spacer></v-spacer>
                    <v-toolbar-items>
                        <v-btn dark flat @click="loginStore">Sign In</v-btn>
                    </v-toolbar-items>
                </v-toolbar>

                <v-layout row class="mt-3">
                    <v-flex xs2 class="mr-2">
                        <div class="text-xs-center">
                            <img src="../assets/images/LeonardoIconAlt.svg" alt="logo" style="width:200px;">
                        </div>
                    </v-flex>
                    <v-flex xs8>
                        <v-alert :value="showAlert" color="error" icon="warning">{{ this.alertMessage }}</v-alert>
                        <v-text-field label="User Name" v-model="userName"></v-text-field>
                        <v-text-field label="Password" v-model="password" type="password"></v-text-field>
                    </v-flex>
                </v-layout>

            </v-card>
        </v-dialog>
    </div>
`,
    props: {
        show: Boolean
    },
    data() {
        return {
            userName: '',
            password: '',
            showAlert: false,
            alertMessage: '',
        }
    },
    methods: {
        loginStore: function() {
            this.alertMessage = '';
            this.showAlert = false;

            let formData = {
                userName: this.userName,
                password: this.password
            };

            if( this.userName != '' && this.password != '') {
                let axiosOptions = {
                    method: 'POST',
                    url: app.dataUrl,
                    data: { 'cred': formData },
                    params: {
                        'action': 'signin'
                    },
                    json: true
                };

                axios(axiosOptions)
                .then( response => { 
                    // If everything is ok, go to thankyou page
                    if( response.data.status == 'true' ) {
                        // Save token in the local storage
                        app.token = response.data.token;
                        app.store.userPrivileges = response.data.privileges;
                        app.store.userLongName = response.data.name;
                        app.store.userLastLogin = response.data.last_login;
                        localStorage.setItem('m2m-admin-token', response.data.token);
                        this.$emit('signedin');
                        this.alertMessage = '';
                        this.showAlert = false;
                        this.userName = '';
                        this.password = '';
                        return;
                    }
                    else {
                        this.alertMessage = response.data.message;
                        this.showAlert = true;
                    }
                })
                .catch(function (error) {
                    console.log(error);
                    this.processing = false;
                });
            }
            else {
                this.alertMessage = 'You enter a the username and password in order to sign in.';
                this.showAlert = true;
            }
        },
    }
})