var orderDetails = Vue.component("m2m-admin-order-detail", {
    template: `<v-app id="orderdetail">
    <v-layout row wrap>
        <v-flex xs7>
            <v-layout column>
                <!-- Order Information -->
                <v-flex>
                    <v-card flat>
                        <v-card-title primary-title>
                            <div class="title" style="width:100%;">
                                Order #{{ this.orderId }} Details 
                                <v-btn small @click="printFactoryOrderDialog = true" class="right" :disabled="statusDisabled">Print Factory Order</v-btn>
                                <v-btn small @click="printReceipt" class="right">Print Customer Receipt</v-btn>
                            </div>
                        </v-card-title>
                        <v-card-text>
                            <v-layout row wrap>
                                <p class="subheading">General</p>
                            </v-layout>
                            <v-layout row wrap>
                                <v-flex xs3 class="mr-2">
                                    <v-text-field :value="this.order.orderDate" label="Date Created" disabled></v-text-field>
                                </v-flex>
                                <v-flex xs4 class="mr-2">
                                    <v-text-field :value="this.order.rep" label="Stylist" disabled></v-text-field>
                                </v-flex>
                                <v-flex xs4>
                                    <v-select :items="this.statusAvailable" label="Status" v-model="order.orderStatus"
                                        @change="setOrderStatus" :disabled="statusDisabled"></v-select>
                                </v-flex>
                            </v-layout>
                            <v-layout row wrap>
                                <v-flex xs12>
                                    <v-divider dark></v-divider>
                                </v-flex>
                            </v-layout>
                            <v-layout row wrap>
                                <!-- Items -->
                                <v-flex xs12 v-for="(item, index) in this.order.items" :key="item.itemId">
                                    <v-layout row>
                                        <v-flex xs8>
                                            <div class="subheading">
                                                <v-icon large>looks_{{ numberToText( index + 1 ) }}</v-icon> {{
                                                item.productName }} <span class="caption">x{{ item.qty }}</span>
                                                <v-tooltip right><v-icon small v-if="item.isCouture == 1" slot="activator">accessibility_new</v-icon><span>Couture Item</span></v-tooltip>
                                            </div>
                                        </v-flex>
                                        <v-flex xs4>
                                            <div class="pt-2 text-xs-right">{{ formatMoney(item.total) }}</div>
                                        </v-flex>
                                    </v-layout>
                                    <v-layout row class="ml-5">
                                        <!-- Modifications -->
                                        <v-flex xs6>
                                            <m2m-item-attributes :editable="true" type="modification" :order-id="order.orderId" 
                                                    :item="item" title="Design Attributes" :items="item.modifications" :productId="item.productId"
                                                    @update="updateOrder">
                                            </m2m-item-attributes>
                                        </v-flex>
                                        <!-- Fabrics -->
                                        <v-flex xs6>
                                            <m2m-item-attributes :editable="true" type="fabric" :order-id="order.orderId" 
                                                    :item="item" title="Fabrics" :items="item.fabrics" :productId="item.productId"
                                                    @update="updateOrder">
                                            </m2m-item-attributes>
                                        </v-flex>
                                    </v-layout>
                                    <v-divider dark></v-divider>
                                </v-flex>

                                <!-- Totals -->
                                <v-flex xs8>
                                    <v-layout column>
                                        <v-flex>
                                            <p class="mb-0 text-xs-right">Special Charges</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="mb-0 text-xs-right">Subtotal</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="mb-0 text-xs-right">Discount</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="mb-0 text-xs-right">Coupon</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="mb-0 text-xs-right">Tax</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="text-xs-right">Total</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="body-2 text-xs-right">Payments</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="body-2 text-xs-right">Balance</p>
                                        </v-flex>
                                    </v-layout>
                                </v-flex>
                                <v-flex xs4>
                                    <v-layout column>
                                        <v-flex>
                                            <p class="mb-0 text-xs-right" v-if="order.specialCharges.length > 0" v-for="sc in this.order.specialCharges" :key="sc.specialChargesId">
                                               [{{ sc.name }}] {{ formatMoney(sc.amount) }}
                                            </p>
                                            <p class="mb-0 text-xs-right" v-if="order.specialCharges.length == 0">
                                               {{ formatMoney(0) }}
                                            </p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="mb-0 text-xs-right">{{ formatMoney(this.order.subtotal) }}</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="mb-0 text-xs-right">[{{ this.order.discountNote }}] - {{
                                                formatMoney(this.order.discount) }}</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="mb-0 text-xs-right">[{{ this.order.couponCode }}] - {{ formatMoney(this.order.couponAmountUsed) }}</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="mb-0 text-xs-right">{{ formatMoney(this.order.tax) }}</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="text-xs-right">{{ formatMoney(this.order.total) }}</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="subheading text-xs-right">{{ formatMoney(this.paymentTotal) }}</p>
                                        </v-flex>
                                        <v-flex>
                                            <p class="subheading text-xs-right">{{ formatMoney(this.order.balance) }}</p>
                                        </v-flex>
                                    </v-layout>
                                </v-flex>
                            </v-layout>
                        </v-card-text>
                    </v-card>
                </v-flex>

                <!-- Payments Information -->
                <v-flex class="mt-2">
                    <v-card flat>
                        <v-card-title primary-title>
                            <div class="title" style="width:100%;">
                                Payments 
                                <v-btn small @click="dialogNewPayment" class="right" v-if="order.balance > 0">Add New Payment</v-btn>
                            </div>
                        </v-card-title>
                        <v-card-text>
                            <v-data-table :headers="this.paymentHeaders" :items="this.order.payments" hide-actions>
                                <template slot="items" slot-scope="props">
                                    <td>{{ props.item.memo }}</td>
                                    <td>{{ props.item.paymentDate }}</td>
                                    <td>{{ props.item.paymentMethod }}</td>
                                    <td>{{ props.item.paymentConfirmationNumber }}</td>
                                    <td class="text-xs-right">{{ formatMoney(props.item.paymentAmount) }}</td>
                                </template>
                                <template slot="footer">
                                    <tr>
                                        <td colspan="4" class="body-2">
                                            Total
                                        </td>
                                        <td class="text-xs-right body-2">
                                            {{ formatMoney(this.paymentTotal) }}
                                        </td>
                                    </tr>
                                </template>
                            </v-data-table>
                        </v-card-text>
                    </v-card>
                </v-flex>

                <!-- Customer Information -->
                <v-flex class="mt-2">
                    <v-card flat>
                        <v-card-title primary-title>
                            <div class="title">Customer Information</div>
                        </v-card-title>
                        <v-card-text>
                            <v-layout row>
                                <v-flex xs3>
                                    <v-text-field :value="this.order.customerName" label="Customer Name" disabled></v-text-field>
                                </v-flex>
                                <v-flex xs3 class="ml-2">
                                    <v-text-field :value="this.order.customerEmail" label="Customer Email" disabled></v-text-field>
                                </v-flex>
                                <v-flex xs3 class="ml-2">
                                    <v-text-field :value="this.order.customerPhone" label="Customer Phone" disabled></v-text-field>
                                </v-flex>
                                <v-flex xs3 class="ml-2">
                                    <v-text-field :value="this.gender" label="Gender" disabled></v-text-field>
                                </v-flex>
                                <v-flex xs3 class="ml-2">
                                    <v-text-field :value="this.order.customerBirthdate" label="Birth Date" disabled></v-text-field>
                                </v-flex>
                            </v-layout>
                            <v-layout row>
                                <v-flex xs1>
                                    <div style="color:hsla(0,0%,100%,.5);font-size:inherit;">Address:</div>
                                </v-flex>
                                <v-flex xs6 class="ml-2" style="color:hsla(0,0%,100%,.5);font-size:inherit;">
                                    {{ this.order.customerAddressLine1 }} <br>
                                    {{ this.order.customerAddressLine2 }} <br v-if="order.customerAddressLine2 != undefined">
                                    {{ this.order.customerCity }} {{ this.order.customerState }}, {{ this.order.customerZipcode }}
                                </v-flex>
                                <v-flex xs3 class="ml-2">
                                    <v-text-field :value="this.order.eventCode == '' ? 'N/A' : this.order.eventCode" label="Event Registry" disabled></v-text-field>
                                </v-flex>
                            </v-layout>
                            <!-- Customer Measurements -->
                            <v-layout row>
                                <v-flex xs12>
                                    <p class="subheading">Measures <v-icon small class="right" @click="tempMeasurements = Object.assign({}, order.measurements); measurementDialog = true">edit</v-icon></p>
                                </v-flex>
                            </v-layout>
                            <v-layout row wrap>
                                <v-flex xs3 v-for="(item, index) in this.order.measurements" :key="index" :class="(index % 4 != 0) ? 'ml-4' : ''" 
                                        v-if="index != 'height_feet' && index != 'height_inch'">
                                    <v-text-field :value="item" :label="toTitleCase(index.replace(new RegExp('_', 'g'), ' '))"
                                        disabled></v-text-field>
                                </v-flex>
                            </v-layout>
                        </v-card-text>
                    </v-card>
                </v-flex>

                <!-- Contact -->
                <v-flex class="mt-2">
                    <v-card flat>
                        <v-card-title primary-title>
                            <div class="title">Contact</div>
                        </v-card-title>
                        <v-card-text>
                            <v-layout row wrap>
                                <v-flex xs3>
                                    <v-text-field :value="this.order.partnerFullname" label="Full Name" disabled></v-text-field>
                                </v-flex>
                                <v-flex xs3 offset-xs1>
                                    <v-text-field :value="this.order.partnerEmail" label="Email" disabled></v-text-field>
                                </v-flex>
                                <v-flex xs3 offset-xs1>
                                    <v-text-field :value="this.order.partnerPhone" label="Phone" disabled></v-text-field>
                                </v-flex>
                            </v-layout>
                        </v-card-text>
                    </v-card>
                </v-flex>
            </v-layout>
        </v-flex>
        <v-flex xs4 class="ml-4">
            <v-layout column>
                <!-- Admin Notes -->
                <v-flex>
                    <v-card flat>
                        <v-card-title primary-title>
                            <div class="title">Order Notes</div>
                        </v-card-title>
                        <v-card-text>
                            <v-layout row wrap>
                                <v-flex xs12 v-for="(note, i) in this.order.notes" :key="i">
                                    <v-layout row>
                                        <v-flex xs6>
                                            <v-chip dark>
                                                <v-avatar>
                                                    <v-icon>account_circle</v-icon>
                                                </v-avatar>
                                                {{ note.author }}
                                            </v-chip>
                                        </v-flex>
                                        <v-flex xs6>
                                            <p class="caption text-xs-right mb-0">{{ note.noteDate }}</p>
                                            <p class="caption text-xs-right mb-0">@ {{ note.noteTime }}</p>
                                        </v-flex>
                                    </v-layout>
                                    <v-layout row class="mt-1">
                                        <v-flex xs12>
                                            <p>{{ note.message }}</p>
                                            <v-divider dark class="mt-2"></v-divider>
                                        </v-flex>
                                    </v-layout>
                                </v-flex>
                                <v-flex xs12>
                                    <v-form ref="form1" v-model="noteValid">
                                        <v-textarea box name="txtNewOrderNote" label="Add New Note" v-model="newOrderNote" required="required"></v-textarea>
                                    </v-form>
                                </v-flex>
                                <v-flex xs12 class="text-xs-right">
                                    <v-btn small @click="saveNote">Add</v-btn>
                                </v-flex>
                            </v-layout>
                        </v-card-text>
                    </v-card>
                </v-flex>

                <!-- Shipping Information -->
                <v-flex class="mt-2">
                    <v-card flat>
                        <v-card-title primary-title>
                            <div class="title">Shipping Information</div>
                        </v-card-title>
                        <v-card-text>
                            <v-layout row wrap>
                                <v-flex xs12>
                                    <v-select :items="carriers" label="Carrier" v-model="carrier"></v-select>
                                </v-flex>
                                <v-flex xs12>
                                    <v-text-field v-model="tracking" label="Tracking Number"></v-text-field>
                                </v-flex>
                                <v-flex xs12 class="text-xs-right">
                                    <v-btn small @click="saveShippingInformation">Save</v-btn>
                                </v-flex>
                            </v-layout>
                        </v-card-text>
                    </v-card>
                </v-flex>

                <!-- Order History -->
                <v-flex class="mt-2">
                    <v-card flat>
                        <v-card-title primary-title>
                            <div class="title">Order History</div>
                        </v-card-title>
                        <v-card-text>
                            <v-layout row wrap>
                                <v-flex xs12>
                                    <v-timeline dense clipped>

                                        <v-slide-x-transition group>
                                            <v-timeline-item v-for="event in timeline" :key="event.date" class="mb-3" :color="event.color" small>
                                                <v-layout justify-space-between>
                                                    <v-flex xs7>
                                                        <v-chip class="white--text ml-0" :color="event.statusColor" label small v-if="event.type == 'status'">
                                                            {{ event.status }}
                                                        </v-chip>
                                                        {{ event.action }}
                                                    </v-flex>
                                                    <v-flex xs5 text-xs-right>
                                                        <p class="caption text-xs-right mb-0">{{ event.date }}</p>
                                                        <p class="caption text-xs-right mb-0">@ {{ event.time }}</p>
                                                    </v-flex>
                                                </v-layout>
                                            </v-timeline-item>
                                        </v-slide-x-transition>
                                    </v-timeline>
                                </v-flex>
                            </v-layout>
                        </v-card-text>
                    </v-card>
                </v-flex>
            </v-layout>
        </v-flex>
    </v-layout>

    <!-- Edit measurement dialog -->
    <v-dialog v-model="measurementDialog" width="600px" persistent>
        <v-card>
            <v-card-title>
                <span class="headline">Edit Measurements</span>
            </v-card-title>
            <v-card-text>
                <v-form ref="form1">
                    <v-layout row>
                        <v-flex xs3>
                            <v-text-field v-model="tempMeasurements.height_feet" :rules="heightFeetRules" label="Height - Feet"
                                suffix="ft" required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.height_inch" :rules="heightInchesRules" label="Height - Inches"
                                suffix="in" required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.weight" :rules="weightRules" label="Weight" suffix="lbs"
                                required></v-text-field>
                        </v-flex>
                    </v-layout>
                    <v-layout row>
                        <v-flex xs3>
                            <v-select v-model="tempMeasurements.watch_hand" :items="watchHandOptions" :rules="[v => !!v || 'A watch habd option is required']"
                                label="Watch Hand" required></v-select>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.neck" :rules="neckRules" label="Neck" suffix="in"
                                required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.sleeve_length_left" :rules="sleeveRules" label="Sleeve Length"
                                suffix="in" required></v-text-field>
                        </v-flex>
                    </v-layout>
                    <v-layout row>
                        <v-flex xs3>
                            <v-text-field v-model="tempMeasurements.sleeve_length_right" :rules="sleeveRules" label="Sleeve Length - Right"
                                suffix="in" required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.bicep" :rules="bicepRules" label="Biceps" suffix="in"
                                required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.wrist" :rules="wristRules" label="Wrist" suffix="in"
                                required></v-text-field>
                        </v-flex>
                    </v-layout>
                    <v-layout row>
                        <v-flex xs3>
                            <v-text-field v-model="tempMeasurements.chest" :rules="chestRules" label="Chest" suffix="in"
                                required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.waist" :rules="waistRules" label="Waist" suffix="in"
                                required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.stomach" :rules="stomachRules" label="Stomach"
                                suffix="in" required></v-text-field>
                        </v-flex>
                    </v-layout>
                    <v-layout row>
                        <v-flex xs3>
                            <v-text-field v-model="tempMeasurements.hips" :rules="hipsRules" label="Hips" suffix="in"
                                required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.leg_length" :rules="legRules" label="Leg Length" suffix="in"
                                required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.thigh" :rules="thighRules" label="Thigh" suffix="in"
                                required></v-text-field>
                        </v-flex>
                    </v-layout>
                    <v-layout row>
                        <v-flex xs3>
                            <v-text-field v-model="tempMeasurements.knee" :rules="kneeRules" label="Knee" suffix="in"
                                required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.calf" label="Calf" suffix="in"></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.cuff" :rules="cuffRules" label="Cuff" suffix="in"
                                required></v-text-field>
                        </v-flex>
                    </v-layout>
                    <v-layout row>
                        <v-flex xs3>
                            <v-text-field v-model="tempMeasurements.crotch" :rules="crotchRules" label="Crotch" suffix="in"
                                required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.shoulder" :rules="shoulderRules" label="Shoulders"
                                suffix="in" required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.coat_sleeve_left" :rules="coatSleeveRules" label="Coat Sleeve Length - Left"
                                suffix="in" required></v-text-field>
                        </v-flex>
                    </v-layout>
                    <v-layout row>
                        <v-flex xs3>
                            <v-text-field v-model="tempMeasurements.coat_sleeve_right" :rules="coatSleeveRules" label="Coat Sleeve Length - Right"
                                suffix="in" required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.jacket_length_front" :rules="jacketFrontRules" label="Jacket Length - Front"
                                suffix="in" required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.jacket_length_back" :rules="jacketBackRules" label="Jacket Length - Back"
                                suffix="in" required></v-text-field>
                        </v-flex>
                    </v-layout>
                    <v-layout row>
                        <v-flex xs3>
                            <v-text-field v-model="tempMeasurements.vest_length_front" :rules="vestFrontRules" label="Vest - Front"
                                suffix="in" required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            <v-text-field v-model="tempMeasurements.vest_length_back" :rules="vestBackRules" label="Vest - Back"
                                suffix="in" required></v-text-field>
                        </v-flex>
                        <v-flex xs3 offset-xs1>
                            
                        </v-flex>
                    </v-layout>
                </v-form>
            </v-card-text>

            <v-divider></v-divider>

            <v-card-actions>
                <v-spacer></v-spacer>
                <v-btn flat @click="measurementDialog = false">
                    Cancel
                </v-btn>
                <v-btn color="primary" flat @click="updateMeasurements">
                    UPDATE
                </v-btn>
            </v-card-actions>
        </v-card>
    </v-dialog>

    <!-- Edit measurement dialog -->
    <v-dialog v-model="paymentDialog" width="600px" persistent>
        <m2m-payment-processor title="Payment Information" :enableIcon="true" :total="orderBalance" 
            :isDialog="true" @close="paymentDialog = false" v-if="order.balance > 0"
            :orderId="orderId" :authToken="authToken" @processed="onPaymentProcessed($event)"></m2m-payment-processor>
    </v-dialog>

    <!-- Factory Order Comment dialog -->
    <v-dialog v-model="printFactoryOrderDialog" width="600px" persistent>
        <v-card>
            <v-card-title>
                <span class="headline">Edit Measurements</span>
            </v-card-title>
            <v-card-text>
                <v-textarea name="comment" label="Order Note" hint="Any message or special instructions for the fabric" v-model="fabricComment"></v-textarea>
            </v-card-text>

            <v-divider></v-divider>

            <v-card-actions>
                <v-spacer></v-spacer>
                <v-btn flat @click="printFactoryOrderDialog = false">
                    Cancel
                </v-btn>
                <v-btn color="primary" flat @click="printFactoryOrder">
                    Print
                </v-btn>
            </v-card-actions>
        </v-card>
    </v-dialog>
</v-app>`,
data: function() {
        return { 
            orderId: app != undefined ? app.store.orderToView : undefined,
            order: {
                orderId: null,
                orderStatus: 'Received',
                balance: 0,
                items: [],
                notes: [],
                payments: [],
                measurements: [],
                history: [],
                specialCharges: [],
                payments: [],
            },
            tempMeasurements: [],
            statusAvailable: [],
            newOrderNote: '',
            paymentHeaders: [
                { text: 'Description', value: 'paymentMemo', align: 'left', sortable: false, width: '30%' },
                { text: 'Date', value: 'paymentDate', align: 'left', sortable: false, width: '30%' },
                { text: 'Method', value: 'paymentMethod', align: 'left', sortable: false, width: '10%' },
                { text: 'Confirmation', value: 'paymentConfirmationNumber', align: 'left', sortable: false, width: '20%' },
                { text: 'Amount', value: 'paymentAmount', align: 'right', sortable: false, width: '10%' },
            ],
            noteValid: false,
            timeline: [],
            prevOrderStatus: '',
            carriers: [
                'DHL',
                'FedEx',
                'UPS',
                'USPS'
            ],
            carrier: '',
            tracking: '',
            measurementDialog: false,
            watchHandOptions: [
                'Left',
                'Right',
                'None'
            ],
            heightFeet: '',
            heightFeetRules: [
                v => !!v || 'Required',
                v => /[3-7]{1}/g.test(v) || 'Feet must be valid'
            ],
            heightInches: '',
            heightInchesRules: [
                v => !!v || 'Required',
                v => v >= 0 && v <= 11 || 'Inches must be valid'
            ],
            weight: '',
            weightRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Weight must be valid'
            ],
            neck: '',
            neckRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Neck must be valid'
            ],
            shoulder: '',
            shoulderRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Shoulders must be valid'
            ],
            coatSleeveLeft: '',
            coatSleeveRight: '',
            coatSleeveRules: [
                v => !!v || 'Required',
                // v => this.tryParseInt(v, false) || 'Coat Sleeve must be valid'
            ],
            sleeveLeft: '',
            sleeveRight: '',
            sleeveRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Sleeve Length must be valid'
            ],
            bicep: '',
            bicepRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Bicep must be valid'
            ],
            wrist: '',
            wristRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Wrist must be valid'
            ],
            chest: '',
            chestRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Chest must be valid'
            ],
            stomach: '',
            stomachRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Stomach must be valid'
            ],
            jacketFront: '',
            jacketFrontRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Jacket Length - Front must be valid'
            ],
            jacketBack: '',
            jacketBackRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Jacket Length - Back must be valid'
            ],
            waist: '',
            waistRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Waist Length must be valid'
            ],
            hips: '',
            hipsRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Hips must be valid'
            ],
            thigh: '',
            thighRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Thigh must be valid'
            ],
            crotch: '',
            crotchRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Crotch must be valid'
            ],
            knee: '',
            kneeRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Knee must be valid'
            ],
            leg: '',
            legRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Leg must be valid'
            ],
            watchHand: '',
            vestFront: '',
            vestFrontRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Vest - Front must be valid'
            ],
            vestBack: '',
            vestBackRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Vest - Back must be valid'
            ],
            calf: '',
            cuff: '',
            cuffRules: [
                v => !!v || 'Required',
                //v => this.tryParseInt(v, false) || 'Cuff must be valid'
            ],
            paymentDialog: false,
            printFactoryOrderDialog: false,
            fabricComment: ''
        }
    },
    computed: {
        paymentTotal: function() {
            let total = 0;
            this.order.payments.forEach(payment => {
                total += parseFloat(payment.paymentAmount);
            });

            return total;
        },
        gender: function() {
            if(this.order.customerGender == 'm')
                return 'Male';
            else if(this.order.customerGender == 'f')
                return 'Female';
            else if(this.order.customerGender == 'n') 
                return 'Neutral';
        },
        orderBalance: function() {
            if( this.order.balance == null || this.order.balance == undefined )
                return 0.0;
            else 
                return parseFloat(this.order.balance);
        },
        authToken: function() {
            if( app.token == undefined || app.token == null)
                return '';

            return app.token;
        },
        statusDisabled: function() {
            if ( this.order.orderStatus != 'Order Received @ Designer Shop' )
                return false;
            else if( this.order.orderStatus == 'Order Received @ Designer Shop' && app.store.userPrivileges.lcs == "1" )
                return false;
            else
                return true;
        },
    },
    created () {
        serverBus.$emit('changePageTitle', 'Order Details');
    },
    mounted: function() {
        this.loadDetails();
    },
    methods: {
        loadDetails: function() {
            axios
                .get( app.dataUrl + '?action=admin.orderdetails&oid=' + this.orderId, { })
                .then( response => { 

                    if(!response.data.status && response.data.signout) {
                        app.signOut();
                    }
                    if(response.data.token) {
                        app.token = response.data.token;
                        localStorage.setItem('m2m-admin-token', response.data.token);
                    }
                    
                    this.order = response.data.data.order;
                    this.order.items = [];
                    this.order.notes = [];
                    this.order.payments = [];
                    this.order.measurements = [];
                    this.order.history = [];
                    this.order.specialCharges = [];

                    if(this.order.carrier != null && this.order.carrier.length > 0)
                        this.carrier = this.order.carrier;
                    if(this.order.trackingNumber != null && this.order.trackingNumber.length > 0)
                        this.tracking = this.order.trackingNumber;
                    
                    let currentItem = '';
                    let itemIndex = -1;
                    for( let i = 0; i < response.data.data.items.length; i++ ) {
                        if( currentItem != response.data.data.items[i].itemId ) {
                            this.order.items.push({
                                itemId: response.data.data.items[i].itemId,
                                productId: response.data.data.items[i].productId,
                                productName: response.data.data.items[i].productName,
                                qty: response.data.data.items[i].qty,
                                price: response.data.data.items[i].price,
                                total: response.data.data.items[i].total,
                                modifications: [],
                                fabrics: [],
                                isCouture: response.data.data.items[i].isCouture
                            });

                            currentItem = response.data.data.items[i].itemId;
                            itemIndex++;
                        }

                        if( response.data.data.items[i].customizationType == 'modification' ) {
                            this.order.items[itemIndex].modifications.push({
                                categoryId: response.data.data.items[i].categoryId,
                                categoryName: response.data.data.items[i].categoryName,
                                optionId: response.data.data.items[i].optionId,
                                optionName: response.data.data.items[i].optionName,
                                optionImage: response.data.data.items[i].optionImage,
                                coutureDescription: response.data.data.items[i].coutureDescription
                            });
                        }
                        else if ( response.data.data.items[i].customizationType == 'fabric' ) {
                            this.order.items[itemIndex].fabrics.push({
                                categoryId: response.data.data.items[i].categoryId,
                                categoryName: response.data.data.items[i].categoryName,
                                optionId: response.data.data.items[i].optionId,
                                optionName: response.data.data.items[i].optionName,
                                optionImage: response.data.data.items[i].optionImage
                            });
                        }
                    }
                    
                    this.order.payments = response.data.data.payments;
                    this.order.notes = response.data.data.notes;
                    this.order.orderStatus = this.order.orderStatus;
                    this.order.measurements = response.data.data.measurements;
                    this.order.history = response.data.data.history;
                    this.order.specialCharges = response.data.data.special_charges;
                    this.timeline = this.order.history.slice().reverse();
                    this.prevOrderStatus = this.order.orderStatus;

                    response.data.data.status.forEach(status => {
                        this.statusAvailable.push(status.status);
                    });
                });  
        },
        toTitleCase: function(str) {
            return str.replace(/\-+/g, ' ').replace(/\w\S*/g, function(txt){
                return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
            });
        },
        numberToText: function(num) {
            let str = '';
            switch(parseInt(num)) {
                case 1:
                    str = 'one';
                    break;
                case 2:
                    str = 'two';
                    break;
                case 3:
                    str = '3';
                    break;
                case 4:
                    str = '4';
                    break;
                case 5:
                    str = '5';
                    break;
                case 6:
                    str = '6';
                    break;
            }

            return str;
        },
        formatMoney: function(n, c, d, t) {
            var c = isNaN(c = Math.abs(c)) ? 2 : c,
              d = d == undefined ? "." : d,
              t = t == undefined ? "," : t,
              s = n < 0 ? "-" : "",
              i = String(parseInt(n = Math.abs(Number(n) || 0).toFixed(c))),
              j = (j = i.length) > 3 ? j % 3 : 0;
          
            return '$' + s + (j ? i.substr(0, j) + t : "") + i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + t) + (c ? d + Math.abs(n - i).toFixed(c).slice(2) : "");
        },
        setOrderStatus: function(v) {

            if ( this.order.orderStatus == this.prevOrderStatus )
                return;

            let form = {
                orderId: this.order.orderId,
                user: 'rtorres', // cambiar esto por el username correcto
                status: this.order.orderStatus, 
            }

            // Save new status for the order
            let axiosOptions = {
                method: 'POST',
                url: app.dataUrl,
                data: { 'form': form },
                params: {
                    'action': 'admin.status'
                },
                json: true
              };

            axios(axiosOptions)
            .then( response => { 
                if( response.data.status == 'error' ) {
                    serverBus.$emit('showErrorDialog', response.data.errors);
                    return;
                }

                if(!response.data.status && response.data.signout) {
                    app.signOut();
                }
                if(response.data.token) {
                    app.token = response.data.token;
                    localStorage.setItem('m2m-admin-token', response.data.token);
                }

                // If everything is ok, add action to order history on UI
                this.order.history.push({
                    type: 'status',
                    status: this.order.orderStatus,
                    action: response.data.data.action,
                    date: response.data.data.date,
                    time: response.data.data.time,
                    color: response.data.data.color,
                    statusColor: response.data.data.statusColor
                });
                this.timeline = this.order.history.slice().reverse();
                this.prevOrderStatus = this.order.orderStatus;
            })
            .catch(function (error) {
                console.log(error);
                serverBus.$emit('showErrorDialog', error);
            });
        },
        saveNote: function() {
            if(this.newOrderNote.length == 0) {
                alert('You must enter a note message first.');
                return;
            }

            let form = {
                orderId: this.order.orderId,
                user: 'rtorres', // cambiar esto por el username correcto
                message: this.newOrderNote, 
            }

            // Save new note for the order
            let axiosOptions = {
                method: 'POST',
                url: app.dataUrl,
                data: { 'form': form },
                params: {
                    'action': 'admin.ordernote'
                },
                json: true
              };

            axios(axiosOptions)
            .then( response => { 
                if( response.data.status == 'error' ) {
                    serverBus.$emit('showErrorDialog', response.data.errors);
                    return;
                }

                if(!response.data.status && response.data.signout) {
                    app.signOut();
                }
                if(response.data.token) {
                    app.token = response.data.token;
                    localStorage.setItem('m2m-admin-token', response.data.token);
                }

                // If everything is ok, add note to order notes on UI
                this.order.notes.push({
                    orderId: this.order.orderId,
                    noteDate: response.data.data.noteDate,
                    noteTime: response.data.data.noteTime,
                    author: response.data.data.author,
                    message: response.data.data.message
                });

                this.newOrderNote = '';
            })
            .catch(function (error) {
                console.log(error);
                serverBus.$emit('showErrorDialog', error);
            });
        },
        saveShippingInformation: function() {
            if(this.carrier == null || this.carrier.length < 1) {
                alert('Your must select a carrier.');
                return;
            }
            if(this.tracking == null || this.tracking.length < 1) {
                alert('Your must enter a tracking number.');
                return;
            }

            let form = {
                orderId: this.order.orderId,
                user: 'rtorres', // cambiar esto por el username correcto
                carrier: this.carrier, 
                trackingNumber: this.tracking
            }

            // Save new note for the order
            let axiosOptions = {
                method: 'POST',
                url: app.dataUrl,
                data: { 'form': form },
                params: {
                    'action': 'admin.ordershipping'
                },
                json: true
              };

            axios(axiosOptions)
            .then( response => { 
                if( response.data.status == 'error' ) {
                    serverBus.$emit('showErrorDialog', response.data.errors);
                    return;
                }

                if(!response.data.status && response.data.signout) {
                    app.signOut();
                }
                if(response.data.token) {
                    app.token = response.data.token;
                    localStorage.setItem('m2m-admin-token', response.data.token);
                }

                this.order.carrier = this.carrier;
                this.order.trackingNumber = this.tracking;
            })
            .catch(function (error) {
                console.log(error);
                serverBus.$emit('showErrorDialog', error);
            });
        },
        printReceipt: function() {
            axios({
                url: app.dataUrl + '?action=receipt&oid=' + this.order.orderId,
                method: 'GET',
                responseType: 'blob'
              }).then((response) => {
                const url = window.URL.createObjectURL(new Blob([response.data]));
                const link = document.createElement('a');
                link.href = url;
                link.setAttribute('download', 'LFA_-_Made_To_Measure_Order_' + this.order.orderId + '.pdf');
                document.body.appendChild(link);
                link.click();
              });
        },
        printFactoryOrder: function() {
            axios({
                url: encodeURI(app.dataUrl + '?action=forder&oid=' + this.order.orderId + '&msg=' + this.fabricComment),
                method: 'GET',
                responseType: 'blob'
              }).then((response) => {
                const url = window.URL.createObjectURL(new Blob([response.data]));
                const link = document.createElement('a');
                link.href = url;
                link.setAttribute('download', 'LFA_-_Made_To_Measure_Order_' + this.order.orderId + '.pdf');
                document.body.appendChild(link);
                link.click();
              });
              
              this.printFactoryOrderDialog = false;
              this.fabricComment = '';
        },
        enableField: function(measure) {
            alert(measure);
        },
        updateOrder: function(e) {
            this.order.notes.push({
                orderId: this.order.orderId,
                noteDate: e.note.noteDate,
                noteTime: e.note.noteTime,
                author: e.note.author,
                message: e.note.message
            });
            this.newOrderNote = '1'; // tweak para que el nuevo comentario aparezca en pantalla.
            this.newOrderNote = '';

            this.order.history.push({
                type: e.history.type,
                status: '',
                action: e.history.action,
                date: e.history.date,
                time: e.history.time,
                color: e.history.color,
                statusColor: e.history.statusColor
            });
            this.timeline = this.order.history.slice().reverse();
        },
        updateMeasurements: function() {
            let form = {
                heightFeet: this.tempMeasurements.height_feet,
                heightInches: this.tempMeasurements.height_inch,
                weight: this.tempMeasurements.weight,
                neck: this.tempMeasurements.neck,
                shoulder: this.tempMeasurements.shoulder,
                coatSleeveLengthLeft: this.tempMeasurements.coat_sleeve_left,
                coatSleeveLengthRight: this.tempMeasurements.coat_sleeve_right,
                sleeveLengthLeft: this.tempMeasurements.sleeve_length_left,
                sleeveLengthRight: this.tempMeasurements.sleeve_length_right,
                bicep: this.tempMeasurements.bicep,
                wrist: this.tempMeasurements.wrist,
                chest: this.tempMeasurements.chest,
                stomach: this.tempMeasurements.stomach,
                jacketLengthFront: this.tempMeasurements.jacket_length_front,
                jacketLengthBack: this.tempMeasurements.jacket_length_back,
                vestLengthFront: this.tempMeasurements.vest_length_front,
                vestLengthBack: this.tempMeasurements.vest_length_back,
                waist: this.tempMeasurements.waist,
                hips: this.tempMeasurements.hips,
                thigh: this.tempMeasurements.thigh,
                crotch: this.tempMeasurements.crotch,
                knee: this.tempMeasurements.knee,
                calf: this.tempMeasurements.calf,
                legLength: this.tempMeasurements.leg_length,
                cuff: this.tempMeasurements.cuff,
                watchHand: this.tempMeasurements.watch_hand,
                orderId: this.order.orderId,
                user: 'rtorres', // cambiar esto por el username correcto
            }

            // Save new note for the order
            let axiosOptions = {
                method: 'POST',
                url: app.dataUrl,
                data: { 'form': form },
                params: {
                    'action': 'admin.ordermeasurements'
                },
                json: true
            };

            axios(axiosOptions)
            .then( response => { 
                if( response.data.status == 'error' ) {
                    serverBus.$emit('showErrorDialog', response.data.errors);
                    return;
                }

                if(!response.data.status && response.data.signout) {
                    app.signOut();
                }
                if(response.data.token) {
                    app.token = response.data.token;
                    localStorage.setItem('m2m-admin-token', response.data.token);
                }

                this.order.measurements = Object.assign({}, this.tempMeasurements);
                this.order.measurements.height = this.order.measurements.height_feet + "' " + this.order.measurements.height_inch + "''";
                this.measurementDialog = false;
                this.tempMeasurements = [];
            })
            .catch(function (error) {
                console.log(error);
                serverBus.$emit('showErrorDialog', error);
            });
        },
        tryParseInt: function(str, defaultValue) {
            var retValue = defaultValue;
            if(str !== null) {
                if(str.length > 0) {
                    if (!isNaN(str)) {
                        // retValue = parseInt(str);
                        retValue = true;
                    }
                }
            }
            return retValue;
        },
        dialogNewPayment: function() {
            this.paymentDialog = true;
        },
        onPaymentProcessed: function(payment) {
            // Close Dialog
            this.paymentDialog = false;

            // Update payments table
            let payments = this.order.payments.slice(0);
            payments.unshift({
                paymentDate: payment.date,
                paymentAmount: payment.amount,
                memo: payment.description,
                paymentMethod: payment.method,
                paymentConfirmationNumber: payment.confirmation
            });
            this.order.payments = payments;
        },
    }
});