var cart = Vue.component('m2m-cart', {
    template: `
    <v-app>
        <v-toolbar color="grey lighten-5" flat>
            <v-toolbar-title class="grey--text darken-1">This is your cart</v-toolbar-title>
            <v-spacer></v-spacer>
            <v-menu v-model="menu" :close-on-content-click="false" offset-y left transition="slide-y-transition">
                <v-btn slot="activator" icon  class="grey--text darken-1"><v-icon>more_vert</v-icon></v-btn>
                <v-card style="max-width:600px !important;">
                    
                    <v-container>
                        <v-layout row wrap align-center>
                            <v-flex xs12 sm3>
                                <v-subheader v-text="'Special charges'"></v-subheader>
                            </v-flex>
                            <v-flex xs12 sm9>
                                <v-select v-model="specialChargesValues" :items="specialChargesOptions" chips label="Special Charges" multiple solo autocomplete></v-select>
                            </v-flex>

                            <v-flex xs12 sm3>
                                <v-subheader v-text="'Discounts'"></v-subheader>
                            </v-flex>
                            <v-flex xs12 sm9>
                                <v-text-field label="Discount Amount" v-model="discountAmount"></v-text-field>
                                <v-textarea label="Discount Note" hint="Note" rows="1" v-model="discountNote" counter="250" maxlength="250"></v-textarea>
                            </v-flex>

                            <v-flex xs12 sm3>
                                <v-subheader v-text="'Coupons'"></v-subheader>
                            </v-flex>
                            <v-flex xs12 sm9>
                                <v-text-field label="Coupon Code" v-model="couponCode"></v-text-field>
                            </v-flex>
                        </v-layout>
                    </v-container>
                    <v-divider></v-divider>
                    <v-card-actions>
                        <v-spacer></v-spacer>

                        <v-btn flat @click="menu = false">Cancel</v-btn>
                        <v-btn color="primary" flat @click="applyChargesNCoupons">Apply</v-btn>
                    </v-card-actions>
                </v-card>
            </v-menu>
        </v-toolbar>
        <v-data-table :headers="headers" :items="items" hide-actions class="elevation-1">
            <template slot="items" slot-scope="props">
                <td class="text-xs-left">
                    <v-btn flat icon color="red" @click="openDialog(props.item)"><v-icon>close</v-icon></v-btn>
                </td>
                <td>
                    <div>{{ props.item.productName }} <v-tooltip right><v-icon small v-if="props.item.isCouture" slot="activator">accessibility_new</v-icon><span>Couture Item</span></v-tooltip></div>
                    <div>
                        <a href="#" class="caption grey--text darken-2" @click="openCustomizationDialog(props.item)">View Customization</a>
                        <v-divider class="mx-2" inset vertical style="height:15px;"></v-divider>
                        <a href="#" class="caption grey--text darken-2" @click="editItem(props.item)">Edit Item</a>
                    </div>
                </td>
                <td class="text-xs-right">
                    {{ formatMoney(props.item.price) }}
                </td>
                <td class="text-xs-right">
                    <v-text-field v-model="props.item.qty" @keydown="qtyChange($event)" required reverse></v-text-field>
                </td>
                <td class="text-xs-right">{{ formatMoney(props.item.price * props.item.qty) }}</td>
            </template>
            <template slot="no-data">
                <v-alert :value="true" color="error" icon="warning">
                    Your cart is currently empty
                </v-alert>
            </template>
            <template slot="footer">
                <tr v-if="this.specialChargesValues.length > 0">
                    <td colspan="3" class="body-2 grey lighten-4">
                        <table>
                            <tr>
                                <td class="pa-0">Special charges</td>
                            </tr>
                            <tr class="pl-3">
                                <td>
                                    <v-list dense style="min-width:200px;background:none;">
                                        <v-list-tile v-for="sCharge in this.specialChargesValues" :key="sCharge.name">
                                            <v-list-tile-content>{{ sCharge.name }}:</v-list-tile-content>
                                            <v-list-tile-content class="align-end">{{ formatMoney(sCharge.amount) }}</v-list-tile-content>
                                        </v-list-tile>
                                    </v-list>
                                </td>
                            </tr>
                        </table>
                    </td>
                    <td colspan="2" class="text-xs-right body-2 grey lighten-4">
                        {{ formatMoney(this.specialChargesTotal) }}
                    </td>
                </tr>
                <tr>
                    <td colspan="3" class="body-2 grey lighten-4">
                        Subtotal
                    </td>
                    <td colspan="2" class="text-xs-right body-2 grey lighten-4">
                        {{ formatMoney(this.subtotal) }}
                    </td>
                </tr>
                <tr v-if="this.discountVisible">
                    <td colspan="3" class="body-2 grey lighten-4">
                        <div>Discount</div>
                        <div>
                            <a href="#" class="caption grey--text darken-2" @click="openDialog('discount')">Remove</a>
                        </div>
                    </td>
                    <td colspan="2" class="text-xs-right body-2 grey lighten-4">
                        <v-tooltip left>
                            <span slot="activator"><v-icon small>info</v-icon> - {{ formatMoney(this.discountInfo.amount) }}</span>
                            <span>{{ this.discountInfo.note }}</span>
                        </v-tooltip>
                    </td>
                </tr>
                <tr v-if="this.couponVisible">
                    <td colspan="3" class="body-2 grey lighten-4">
                        <div>Coupon [{{ this.couponInfo.coupon_code }}]</div>
                        <div>
                            <a href="#" class="caption grey--text darken-2" @click="openDialog('coupon')">Remove</a>
                        </div>
                    </td>
                    <td colspan="2" class="text-xs-right body-2 grey lighten-4">
                        <span> - {{ formatMoney(this.couponInfo.balance) }}</span>
                    </td>
                </tr>
                <tr>
                    <td colspan="3" class="body-2 grey lighten-4">
                        Tax
                    </td>
                    <td colspan="2" class="text-xs-right body-2 grey lighten-4">
                        {{ formatMoney(this.tax) }}
                    </td>
                </tr>
                <tr>
                    <td colspan="3" class="title grey lighten-4">
                    Total
                    </td>
                    <td colspan="2" class="text-xs-right title grey lighten-4">
                        <span class="green--text darken-2">{{ formatMoney(this.total) }}</span>
                    </td>
                </tr>
            </template>
        </v-data-table>

        <div :class="items.length < 1 || this.total <= 0 ? 'hidden' : ''">
            <router-link to="/checkout"><v-btn color="red" dark large fixed bottom right>Continue to Checkout</v-btn></router-link>
        </div>

        <v-dialog v-model="dialog" persistent max-width="290">
            <v-card>
                <v-card-title class="headline">Warning!</v-card-title>
                <v-card-text>{{ this.dialogText }}</v-card-text>
                <v-card-actions>
                    <v-spacer></v-spacer>
                    <v-btn color="red darken-1" flat @click="removeItem()">Yes</v-btn>
                    <v-btn color="green darken-1" flat @click="closeDialog()">No</v-btn>
                </v-card-actions>
            </v-card>
        </v-dialog>
        <v-dialog v-model="itemDialog" scrollable  max-width="500">
            <v-card>
                <v-card-title>Customization Details</v-card-title>
                <v-divider></v-divider>
                <v-card-text style="height: 300px;" class="pt-0 pb-0">
                    <v-container fluid fill-width class="pt-0 pb-0">
                        <v-layout row wrap fluid>
                            <v-flex xs6  v-if="selectedItem != null">
                                <v-list two-line subheader>
                                    <v-subheader>Modifications</v-subheader>

                                    <v-list-tile avatar v-for="mod in selectedItem.modifications" :key="mod.catId">
                                        <v-list-tile-avatar>
                                            <img :src="mod.optionImage">
                                        </v-list-tile-avatar>
                                        <v-list-tile-content>
                                            <v-list-tile-title class="caption">{{ toTitleCase(mod.category) }}</v-list-tile-title>
                                            <v-list-tile-sub-title class="caption">{{ toTitleCase(mod.option) }}</v-list-tile-sub-title>
                                            <v-list-tile-sub-title class="caption" v-if="selectedItem.isCouture">{{ mod.description }}</v-list-tile-sub-title>
                                        </v-list-tile-content>
                                    </v-list-tile>
                                </v-list>
                            </v-flex>
                            <v-flex xs6  v-if="selectedItem != null">
                                <v-list two-line subheader>
                                    <v-subheader>Fabrics</v-subheader>

                                    <v-list-tile avatar v-for="fab in selectedItem.fabrics" :key="fab.fabric_option_id">
                                        <v-list-tile-avatar>
                                            <img :src="fab.fabric_image">
                                        </v-list-tile-avatar>
                                        <v-list-tile-content>
                                            <v-list-tile-title class="caption">{{ toTitleCase(fab.fabric_option) }}</v-list-tile-title>
                                            <v-list-tile-sub-title class="caption">{{ toTitleCase(fab.fabric) }}</v-list-tile-sub-title>
                                        </v-list-tile-content>
                                    </v-list-tile>
                                </v-list>
                            </v-flex>
                        </v-layout>
                    </v-container>
                </v-card-text>
                <v-divider></v-divider>
                <v-card-actions>
                    <v-btn color="blue darken-1" flat @click.native="itemDialog = false" style="margin-left:auto; margin-right:0;">Close</v-btn>
                </v-card-actions>
            </v-card>
        </v-dialog>
        <v-snackbar v-model="snackbar" color="error" :top="true" :multi-line="false" :timeout="5000">
            <div>
                <v-icon left class="pl-0 pr-0">warning</v-icon>
                <span class="pl-0">{{ snackbarText }}</span>
            </div>
        </v-snackbar>
    </v-app>`,
    data: function() {
        return {
            items: [],
            headers: [
                { text: '', value: '', sortable: false, align: 'left', width: '1%' },
                { text: 'Product', value: 'productName', sortable: false, align: 'left', width: '69%' },
                { text: 'Price', value: 'price', sortable: false, align: 'right', width: '10%' },
                { text: 'Qty', value: 'qty', sortable: false, align: 'right', width: '10%' },
                { text: 'Total', value: 'total', sortable: false, align: 'right', width: '10%' }
            ],
            selectedItem: null,
            dialog: false,
            itemDialog: false,
            menu: false,
            specialChargesValues: [],
            specialChargesOptions: [
                { text: 'foo $15.00', value: { name: 'Foo', amount: 15.00 } },
                { text: 'boo $100.00', value: { name: 'Boo', amount: 100.00 } },
                { text: 'baa $52.00', value: { name: 'Baa', amount: 52.00 } },
            ],
            discountAmount: null,
            discountNote: null,
            couponCode: null,
            snackbar: false,
            snackbarText: 'Item added to cart',
            dialogText: ''
        };
    },
    computed: {
        subtotal: function() {
            let subtotal = this.specialChargesTotal;
            for( let i = 0; i < app.store.cart.length; i++ ) {
                subtotal += app.store.cart[i].price * app.store.cart[i].qty;
            }

            return subtotal;
        },
        tax: function() {
            let couponAmt = 0;
            if(!_.isEmpty(this.couponInfo))
                couponAmt = this.couponInfo.balance;

            return (this.subtotal - this.discountInfo.amount - couponAmt) * 0.115 > 0 ? (this.subtotal - this.discountInfo.amount - couponAmt) * 0.115 : 0;
        },
        total: function() {
            let couponAmt = 0;
            if(!_.isEmpty(this.couponInfo))
                couponAmt = this.couponInfo.balance;

            return this.subtotal - this.discountInfo.amount - couponAmt + this.tax > 0 ? this.subtotal - this.discountInfo.amount - couponAmt + this.tax : 0;
        },
        discountVisible: function() {
            return app.store.discount.amount > 0;
        },
        discountInfo: function() {
            return app.store.discount;
        },
        couponVisible: function() {
            return !_.isEmpty(app.store.coupon);
        },
        couponInfo: function() {
            return app.store.coupon;
        },
        couponAmountUsed: function() {
            let couponAmt = 0;
            if(!_.isEmpty(this.couponInfo))
                couponAmt = this.couponInfo.balance;

            if( couponAmt > this.subtotal - this.discountInfo.amount )
                return couponAmt - (this.subtotal - this.discountInfo.amount);
            else
                return couponAmt;
        },
        specialChargesTotal: function() {
            let total = 0;
            this.specialChargesValues.forEach(sCharge => {
                total += parseFloat(sCharge.amount.split(',').join(''));
            });

            return parseFloat(total);
        },
    },
    created () {
        app.pageStack.splice(1);
        app.pageStack[0].disabled = false;
        app.pageStack.push( {
            text: 'Cart',
            disabled: true,
            href: '#/cart'
        });

        this.initialize();
    },
    mounted() {
        // Load special charges from db
        axios
            .get( app.dataUrl + '?action=specialcharges', { headers: { Authorization: app.authKey } })
            .then( response => { 
                this.specialChargesOptions = [];

                if(response.data.status == 'true') {
                    response.data.data.forEach(specialCharge => {
                        this.specialChargesOptions.push({
                            text: specialCharge.name + ' | ' + this.formatMoney(specialCharge.amount), 
                            value: specialCharge
                        });
                    });
                }
            });
    },
    methods: {
        initialize() {
            this.items = app.store.cart;
            this.specialChargesValues = app.store.specialCharges;
        },
        formatMoney: function(n, c, d, t) {
            var c = isNaN(c = Math.abs(c)) ? 2 : c,
              d = d == undefined ? "." : d,
              t = t == undefined ? "," : t,
              s = n < 0 ? "-" : "",
              i = String(parseInt(n = Math.abs(Number(n) || 0).toFixed(c))),
              j = (j = i.length) > 3 ? j % 3 : 0;
          
            return '$' + s + (j ? i.substr(0, j) + t : "") + i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + t) + (c ? d + Math.abs(n - i).toFixed(c).slice(2) : "");
        },
        qtyChange: function(e, item) {
            // Allow: backspace, delete, tab, escape, enter and .
            if ($.inArray(e.keyCode, [46, 8, 9, 27, 13, 110, 190]) !== -1 ||
                // Allow: Ctrl/cmd+A
            (e.keyCode == 65 && (e.ctrlKey === true || e.metaKey === true)) ||
                // Allow: Ctrl/cmd+C
            (e.keyCode == 67 && (e.ctrlKey === true || e.metaKey === true)) ||
                // Allow: Ctrl/cmd+X
            (e.keyCode == 88 && (e.ctrlKey === true || e.metaKey === true)) ||
                // Allow: home, end, left, right
            (e.keyCode >= 35 && e.keyCode <= 39)) {
                // let it happen, don't do anything
                return;
            }

            // Ensure that it is a number and stop the keypress
            if ((e.shiftKey || (e.keyCode < 48 || e.keyCode > 57)) && (e.keyCode < 96 || e.keyCode > 105)) {
                e.preventDefault();
            }
        },
        openDialog: function(item) {
            if( item == 'discount' ) 
                this.dialogText = "Are you sure you want to remove the discount?";
            else if( item == 'coupon' ) {
                this.dialogText = 'Are you sure you want to remove the coupon?';
            }
            else 
                this.dialogText = "Are your sure you want to remove this item from your cart? You will loose all the customization made.";

            this.selectedItem = item;
            this.dialog = true;
        },
        removeItem: function () {
            if( this.selectedItem == 'discount' )
                this.removeDiscount();
            else if( this.selectedItem == 'coupon' ) {
                this.removeCoupon();
            }
            else {
                const index = this.items.indexOf(this.selectedItem);
                this.items.splice(index, 1);
            }

            this.closeDialog();
        },
        closeDialog: function() {
            this.dialog = false;
        },
        closeCustomizationDialog: function() {
            this.itemDialog = false;
        },
        openCustomizationDialog: function(item) {
            this.selectedItem = item;
            this.itemDialog = true;
        },
        editItem: function(item) {
            app.store.typeId = item.typeId;
            app.store.modifications = JSON.parse(JSON.stringify(item.modifications)); // Use JSON to deep clone the modification array
            app.store.fabrics = JSON.parse(JSON.stringify(item.fabrics)); // Use JSON to deep clone the fabrics array
            app.store.productId = item.productId;
            app.store.availableFabrics = [];
            app.store.createdFabrics = [];
            item.fabrics.forEach(fabric => {
                app.store.availableFabrics.push({
                    fabric_id: fabric.fabric_id,
                    image_url: fabric.fabric_image,
                    name: fabric.fabric
                });
            });

            app.store.isEdit = true;
            app.store.editItemIndex = _.indexOf(app.store.cart, item);

            router.push('/designer');
        },
        toTitleCase: function (str) {
            return str.replace(/\-+/g, ' ').replace(/\w\S*/g, function(txt){
                return txt.charAt(0).toUpperCase() + txt.substr(1).toLowerCase();
            });
        },
        applyChargesNCoupons: function() {

            // Add special charges to cart if everything is good
            app.store.specialCharges = [];
            this.specialChargesValues.forEach(item => {
                app.store.specialCharges.push(item);
            });

            // Validate discount amount and note
            if( this.discountAmount == null || this.discountAmount == undefined ) {
                //this.menu = false;
                //return;
            }

            if( (this.discountNote == null || this.discountNote == undefined) && this.discountAmount != null ) {
                // show message
                this.snackbarText = 'You must enter a note.';
                this.snackbar = true;
                return;
            }
            
            let regex  = /^[1-9]\d*(((,\d{3}){1})?(\.\d{0,2})?)$/;
            if( this.discountAmount != null && !regex.test(this.discountAmount) ) {
                // show message
                this.snackbarText = 'You must enter a valid amount.';
                this.snackbar = true;
                return;
            }

            // Validate coupon code
            if( this.couponCode == null || this.couponCode == undefined || this.couponCode.length == 0 ) {
                this.menu = false;
            }
            // Look for the coupon information
            else {
                axios
                .get( app.dataUrl + '?action=coupon&c=' + this.couponCode, { headers: { Authorization: app.authKey } })
                .then( response => { 
                    if(response.data.status == 'true') {
                        app.store.coupon = response.data.data;
                    }
                    else {
                        // show message
                        this.snackbarText = response.data.message;
                        this.snackbar = true;
                    }

                    this.couponCode = null;
                });
            }
            
            // Add coupon to cart if everything is good
            app.store.discount.amount = this.discountAmount;
            app.store.discount.note = this.discountNote;

            this.discountAmount = this.discountNote = null;
            this.menu = false;
        },
        removeDiscount: function () {
            app.store.discount.amount = 0;
            app.store.discount.note = '';
        },
        removeCoupon: function() {
            app.store.coupon = {};
        }
    }
});